#
# BuildType.cmake
# Functions for manipulating Doxygen related variables.
#

#
# This file is part of libawstoolbox.
# Copyright (C) 2008-2022 by Alan Wise <awisesoftware@gmail.com>.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#

# Copied with modifications from:
# https://www.kitware.com/cmake-and-the-default-build-type/

# Set a default build type if none was specified.
if("${DEFAULT_BUILD_TYPE}" STREQUAL "")
  set(DEFAULT_BUILD_TYPE "Release")
endif()

if(NOT CMAKE_BUILD_TYPE AND NOT CMAKE_CONFIGURATION_TYPES)
  message(STATUS "")
  message(STATUS
      "Build type not set. Defaulting to \"${DEFAULT_BUILD_TYPE}\".")
  message(STATUS "")
  set(CMAKE_BUILD_TYPE "${DEFAULT_BUILD_TYPE}"
      CACHE STRING "Build type." FORCE)
  # Set the possible values of build type for cmake-gui.
  set_property(CACHE CMAKE_BUILD_TYPE PROPERTY STRINGS "Debug" "Release")

endif()

function(SetBuildTypeFlags)
  if(ARGC GREATER 0)
    message(FATAL_ERROR "Too many parameters.")
  endif()
  if("${CMAKE_BUILD_TYPE}" MATCHES "[Dd][Ee][Bb][Uu][Gg]")
    set(DEBUGBUILD ON PARENT_SCOPE)
  elseif("${CMAKE_BUILD_TYPE}" MATCHES "[Rr][Ee][Ll][Ee][Aa][Ss][Ee]")
    set(RELEASEBUILD ON PARENT_SCOPE)
  endif()
endfunction()


#
# BuildType.cmake
#
