#
# TestExecutable.cmake
# Functions for adding test executables.
#

#
# This file is part of libawstoolbox.
# Copyright (C) 2008-2022 by Alan Wise <awisesoftware@gmail.com>.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#

# Set a default build type if none was specified.
#if("${DEFAULT_BUILD_TYPE}" STREQUAL "")
#  set(DEFAULT_BUILD_TYPE "Release")
#endif()
#
#if(NOT CMAKE_BUILD_TYPE AND NOT CMAKE_CONFIGURATION_TYPES)
#  message(STATUS "")
#  message(STATUS
#      "Build type not set. Defaulting to \"${DEFAULT_BUILD_TYPE}\".")
#  message(STATUS "")
#  set(CMAKE_BUILD_TYPE "${DEFAULT_BUILD_TYPE}"
#      CACHE STRING "Build type." FORCE)
#  # Set the possible values of build type for cmake-gui.
#  set_property(CACHE CMAKE_BUILD_TYPE PROPERTY STRINGS "Debug" "Release")
#
#endif()
#
#function(SetBuildTypeFlags)
#  if(ARGC GREATER 0)
#    message(FATAL_ERROR "Too many parameters.")
#  endif()
#  if("${CMAKE_BUILD_TYPE}" MATCHES "[Dd][Ee][Bb][Uu][Gg]")
#    set(DEBUGBUILD ON PARENT_SCOPE)
#  elseif("${CMAKE_BUILD_TYPE}" MATCHES "[Rr][Ee][Ll][Ee][Aa][Ss][Ee]")
#    set(RELEASEBUILD ON PARENT_SCOPE)
#  endif()
#endfunction()

function(add_test_executable)
  set(OPT TEST)
  set(OVA DEPENDENT)
  set(MVA COMPILE_DEFINITIONS COMPILE_FEATURES COMPILE_OPTIONS
      INCLUDE_DIRECTORIES LINK_LIBRARIES SOURCES)
  cmake_parse_arguments(PARSE_ARGV 1 ATE "${OPT}" "${OVA}" "${MVA}")

  add_executable(${ARGV0} EXCLUDE_FROM_ALL ${ATE_SOURCES})
  if(NOT "${ATE_COMPILE_DEFINITIONS}" STREQUAL "")
    target_compile_definitions(${ARGV0} ${ATE_COMPILE_DEFINITIONS})
  endif()
  if(NOT "${ATE_COMPILE_FEATURES}" STREQUAL "")
    target_compile_features(${ARGV0} ${ATE_COMPILE_FEATURES})
  endif()
  if(NOT "${ATE_COMPILE_OPTIONS}" STREQUAL "")
    target_compile_options(${ARGV0} ${ATE_COMPILE_OPTIONS})
  endif()
  if(NOT "${ATE_DEPENDENT}" STREQUAL "")
    add_dependencies(${ATE_DEPENDENT} ${ARGV0})
  endif()
  if(NOT "${ATE_INCLUDE_DIRECTORIES}" STREQUAL "")
    target_include_directories(${ARGV0} ${ATE_INCLUDE_DIRECTORIES})
  endif()
  if(NOT "${ATE_LINK_LIBRARIES}" STREQUAL "")
    target_link_libraries(${ARGV0} ${ATE_LINK_LIBRARIES})
  endif()
  add_test(NAME ${ARGV0} COMMAND $<TARGET_FILE:${ARGV0}>)
endfunction()


#
# TestExecutable.cmake
#
