#
# TextFileToIncludeFile.cmake
# Converts a text file into an C include file.
#

#
# This file is part of libawstoolbox.
# Copyright (C) 2008-2022 by Alan Wise <awisesoftware@gmail.com>.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#

function(TextFileToIncludeFile)
  if(NOT ${ARGC} EQUAL 3)
    if (${ARGC} LESS 3)
      SET(MSG0 "Too few arguments.")
    else()
      SET(MSG0 "Too many arguments.")
    endif()

    set(MSG1 "Usage:TextFileToIncludeFile inputfile variablename outputfile")

    message(FATAL_ERROR "${MSG0}\n${MSG1}")

  else()
    file(READ "${ARGV0}" TEXT)
    string(REGEX REPLACE "\"" "\\\\\"" ESCAPEQUOTES "${TEXT}")
    string(REGEX REPLACE "\n" "\\\\n\"\n\"" CCODE "${ESCAPEQUOTES}")
    set(INCLUDETEXT "const char ${ARGV1}[]=\n\"${CCODE}\";")
    file(WRITE "${ARGV2}" "${INCLUDETEXT}")

  endif()

endfunction()

#
# TextFileToIncludeFile.cmake
#
