/**
*** \file preferences_test.cpp
*** \brief Module 'preferences' unit test file.
*** \details Unit test file for the 'preferences' module.
**/

/*
** This file is part of moonphase.
** Copyright (C) 2014-2023 Alan Wise <awisesoftware@gmail.com>.
**
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation, either version 3 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/


/**
*** \internal
*** \brief preferences_test.cpp identifier.
*** \details Identifier for preferences_test.cpp.
*** \endinternal
**/
#define   PREFERENCES_TEST_CPP

/* GCOVR_ EXCL_START LCOV_ EXCL_START */


/****
*****
***** INCLUDES
*****
****/

/**
*** \brief Master test suite name.
*** \details The name of the master test suite.
**/
#define   BOOST_TEST_MODULE   "Preferences"
#include  <boost/test/included/unit_test.hpp>

#include  "preferences.cpp"
#include  "preferencesmanager_stub.h"


/****
*****
***** DEFINES
*****
****/



/****
*****
***** DATA TYPES
*****
****/

typedef struct structOPTIONVALUES
{
  bool DefaultToGMTFlag;
  bool DefaultToMetricUnitsFlag;
  double Latitude;
  double Longitude;
} OPTIONVALUES_T;


/****
*****
***** CLASSES
*****
****/


/****
*****
***** PROTOTYPES
*****
****/


/****
*****
***** DATA
*****
****/



/****
*****
***** VARIABLES
*****
****/


/****
*****
***** FUNCTIONS
*****
****/

void InitializeOptionValues(OPTIONVALUES_T const *pInitialValues,
    PREFERENCES_C::MOONDATA_C::OPTIONS_C &Preferences)
{
  Preferences.SetDefaultToGMTFlag(pInitialValues->DefaultToGMTFlag);
  Preferences.SetDefaultToMetricUnitsFlag(
      pInitialValues->DefaultToMetricUnitsFlag);
  Preferences.SetLatitude(pInitialValues->Latitude);
  Preferences.SetLongitude(pInitialValues->Longitude);

  return;
}


/****
*****
***** TESTS
*****
****/

BOOST_AUTO_TEST_SUITE(Module__Preferences)
//#include  "preferences_test_preferences.cpp"
//#include  "preferences_test_preferences_application.cpp"
//#include  "preferences_test_preferences_moondata.cpp"
//#include  "preferences_test_preferences_moondata_options.cpp"
//NO #include  "preferences_test_preferences_moondata_paneltooltip.cpp"
//#include  "preferences_test_preferences_moondata_panel.cpp"
//#include  "preferences_test_preferences_moondata_tooltip.cpp"
//GIT #include  "preferences_test_preferences_moondata_panel_dialogdata.cpp"
#include  "preferences_test_preferences_moondata_panel_display.cpp"
BOOST_AUTO_TEST_SUITE_END()

/* LCOV_ EXCL_STOP GCOVR_ EXCL_STOP */


#undef    PREFERENCES_TEST_CPP


/**
*** preferences_test.cpp
**/
