/**
*** \file preferences_test_preferences_application.cpp
*** \brief Class 'PREFERENCES_C::APPLICATION_C' unit test file.
*** \details Unit test file for the 'PREFERENCES_C::APPLICATION_C' class.
**/

/*
** This file is part of moonphase.
** Copyright (C) 2014-2023 Alan Wise <awisesoftware@gmail.com>.
**
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation, either version 3 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/


/**
*** \internal
*** \brief preferences_test_preferences_application.cpp identifier.
*** \details Identifier for preferences_test_preferences_application.cpp.
*** \endinternal
**/
#define   PREFERENCES_TEST_PREFERENCES_APPLICATION_CPP


/****
*****
***** INCLUDES
*****
****/


/****
*****
***** DEFINES
*****
****/


/****
*****
***** DATA TYPES
*****
****/

typedef struct structAPPLICATIONVALUES
{
  std::string AnimationPathname;
  COLOR_C BackgroundColor;
  bool ConfirmDiscardFlag;
  bool ConfirmQuitFlag;
  bool RemindOncePerSessionFlag;
  bool StillRunningReminderFlag;
  bool UnsavedChangesReminderFlag;
  bool UseOpaqueBackgroundFlag;
} APPLICATIONVALUES_T;


/****
*****
***** CLASSES
*****
****/


/****
*****
***** PROTOTYPES
*****
****/


/****
*****
***** DATA
*****
****/

struct
{
  APPLICATIONVALUES_T Preferences0;
  APPLICATIONVALUES_T Preferences1;
  bool Equal;
} static const f_pEqualityOperatorTestCases[]=
{
  /* Cycle a 'false' through the first set of comparisions. */
  {
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
    { "A",COLOR_C(0,.5,1),false,false,false,false,false,false },
    { "B",COLOR_C(0,.5,1),false,false,false,false,false,false },
    false
  },
  {
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
    { "A",COLOR_C(0,.5,1), true,false,false,false,false,false },
    { "A",COLOR_C(0,.5,1),false,false,false,false,false,false },
    false
  },
  {
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
    { "A",COLOR_C(0,.5,1),false, true,false,false,false,false },
    { "A",COLOR_C(0,.5,1),false,false,false,false,false,false },
    false
  },
  {
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
    { "A",COLOR_C(0,.5,1),false,false,false, true,false,false },
    { "A",COLOR_C(0,.5,1),false,false,false,false,false,false },
    false
  },
  {
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
    { "A",COLOR_C(0,.5,1),false,false,false,false, true,false },
    { "A",COLOR_C(0,.5,1),false,false,false,false,false,false },
    false
  },
  {
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
    { "A",COLOR_C(0,.5,1),false,false,false,false,false, true },
    { "A",COLOR_C(0,.5,1),false,false,false,false,false,false },
    false
  },
  /* Send (true,false) and (false,true) through the first 'if' statement. */
  {
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
    { "A",COLOR_C(0,.5,1),false,false,false,false,false,false },
    { "A",COLOR_C(0,.5,1),false,false,false,false,false,false },
    true
  },
  {
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
    { "A",COLOR_C(0,.5,1),false,false,false, true,false,false },
    { "A",COLOR_C(0,.5,1),false,false,false,false,false,false },
    false
  },
  /* Send (true,true) through the first 'if' statement, and then
    (true,false), (false,true) through the assignment. */
  {
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
    { "A",COLOR_C(0,.5,1),false,false, true, true,false,false },
    { "A",COLOR_C(0,.5,1),false,false,false, true,false,false },
    false
  },
  {
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
    { "A",COLOR_C(0,.5,1),false,false,false, true,false,false },
    { "B",COLOR_C(0,.5,1),false,false,false, true,false,false },
    false
  },
  /* Send (true,false) and (false,true) through the second 'if' statement. */
  {
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
    { "A",COLOR_C(0,.5,1),false,false,false,false,false,false },
    { "A",COLOR_C(0,.5,1),false,false,false,false,false,false },
    true
  },
  {
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
    { "A",COLOR_C(0,.5,1),false,false,false,false,false, true },
    { "A",COLOR_C(0,.5,1),false,false,false,false,false,false },
    false
  },
  /* Send (true,true) through the first 'if' statement, and then
    (true,false), (false,true) through the assignment. */
  {
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
    { "A",COLOR_C(0,0,0) ,false,false,false,false,false, true },
    { "A",COLOR_C(0,.5,1),false,false,false,false,false, true },
    false
  },
  {
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
    { "A",COLOR_C(0,.5,1),false,false,false,false,false, true },
    { "B",COLOR_C(0,.5,1),false,false,false,false,false, true },
    false
  }
};
static int const f_EqualityOperatorTestCaseCount=
    sizeof(f_pEqualityOperatorTestCases)/sizeof(*f_pEqualityOperatorTestCases);

struct
{
  APPLICATIONVALUES_T Values;
} static const f_pLoadTestCases[]=
{
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
  { "Path",COLOR_C(1,1,1), true,false,false,false,false,false },
  { "Path",COLOR_C(1,1,1),false, true,false,false,false,false },
  { "Path",COLOR_C(1,1,1),false,false, true,false,false,false },
  { "Path",COLOR_C(1,1,1),false,false,false, true,false,false },
  { "Path",COLOR_C(1,1,1),false,false,false,false, true,false },
  { "Path",COLOR_C(1,1,1),false,false,false,false,false, true }
};
static int const f_LoadTestCaseCount=
    sizeof(f_pLoadTestCases)/sizeof(*f_pLoadTestCases);

struct
{
  APPLICATIONVALUES_T Values;
} static const f_pSaveTestCases[]=
{
    /* AP BC              CDF   CQF   ROPSF SRRF  UCRF  UOBF */
  { "Path",COLOR_C(1,1,1), true,false,false,false,false,false },
  { "Path",COLOR_C(1,1,1),false, true,false,false,false,false },
  { "Path",COLOR_C(1,1,1),false,false, true,false,false,false },
  { "Path",COLOR_C(1,1,1),false,false,false, true,false,false },
  { "Path",COLOR_C(1,1,1),false,false,false,false, true,false },
  { "Path",COLOR_C(1,1,1),false,false,false,false,false, true }
};
static int const f_SaveTestCaseCount=
    sizeof(f_pSaveTestCases)/sizeof(*f_pSaveTestCases);


/****
*****
***** VARIABLES
*****
****/


/****
*****
***** FUNCTIONS
*****
****/

void InitializeApplicationValues(APPLICATIONVALUES_T const *pInitialValues,
    PREFERENCES_C::APPLICATION_C &Preferences)
{
  Preferences.SetAnimationPathname(pInitialValues->AnimationPathname);
  Preferences.SetBackgroundColor(pInitialValues->BackgroundColor);
  Preferences.SetConfirmDiscardFlag(pInitialValues->ConfirmDiscardFlag);
  Preferences.SetConfirmQuitFlag(pInitialValues->ConfirmQuitFlag);
  Preferences.SetRemindOncePerSessionFlag(
      pInitialValues->RemindOncePerSessionFlag);
  Preferences.SetStillRunningReminderFlag(
      pInitialValues->StillRunningReminderFlag);
  Preferences.SetUnsavedChangesReminderFlag(
      pInitialValues->UnsavedChangesReminderFlag);
  Preferences.SetUseOpaqueBackgroundFlag(
      pInitialValues->UseOpaqueBackgroundFlag);

  return;
}


/****
*****
***** TESTS
*****
****/

BOOST_AUTO_TEST_SUITE(Class__PREFERENCES_APPLICATION)
  BOOST_AUTO_TEST_SUITE(Function__DefaultConstructor)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      std::unique_ptr<PREFERENCES_C::APPLICATION_C> pPreferences;


      pPreferences.reset(new PREFERENCES_C::APPLICATION_C());

      BOOST_CHECK(pPreferences.get()!=nullptr);
      BOOST_CHECK(pPreferences->GetAnimationPathname()==
          fc_pDefaultAnimationPathname);
      BOOST_CHECK(pPreferences->GetBackgroundColor()==
          fc_DefaultTrayIconBackgroundColor);
      BOOST_CHECK(pPreferences->GetConfirmDiscardFlag()==
          fc_DefaultConfirmDiscardFlag);
      BOOST_CHECK(pPreferences->GetConfirmQuitFlag()==
          fc_DefaultConfirmQuitFlag);
      BOOST_CHECK(pPreferences->GetRemindOncePerSessionFlag()==
          fc_DefaultRemindOncePerSessionFlag);
      BOOST_CHECK(pPreferences->GetStillRunningReminderFlag()==
          fc_DefaultStillRunningReminderFlag);
      BOOST_CHECK(pPreferences->GetUnsavedChangesReminderFlag()==
          fc_DefaultUnsavedChangesReminderFlag);
      BOOST_CHECK(pPreferences->GetUseOpaqueBackgroundFlag()==
          fc_DefaultUseOpaqueBackgroundFlag);

      delete pPreferences.release();
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Functions__GetAnimationPathname_SetAnimationPathname)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::APPLICATION_C Preferences;
      std::string const Pathname="test.jpg";


      BOOST_CHECK(Preferences.GetAnimationPathname()==
          fc_pDefaultAnimationPathname);
      Preferences.SetAnimationPathname(Pathname);
      BOOST_CHECK(Preferences.GetAnimationPathname()==Pathname);
      BOOST_CHECK(Preferences.GetBackgroundColor()==
          fc_DefaultTrayIconBackgroundColor);
      BOOST_CHECK(Preferences.GetConfirmDiscardFlag()==
          fc_DefaultConfirmDiscardFlag);
      BOOST_CHECK(Preferences.GetConfirmQuitFlag()==
          fc_DefaultConfirmQuitFlag);
      BOOST_CHECK(Preferences.GetRemindOncePerSessionFlag()==
          fc_DefaultRemindOncePerSessionFlag);
      BOOST_CHECK(Preferences.GetStillRunningReminderFlag()==
          fc_DefaultStillRunningReminderFlag);
      BOOST_CHECK(Preferences.GetUnsavedChangesReminderFlag()==
          fc_DefaultUnsavedChangesReminderFlag);
      BOOST_CHECK(Preferences.GetUseOpaqueBackgroundFlag()==
          fc_DefaultUseOpaqueBackgroundFlag);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Functions__GetBackgroundColor_SetBackgroundColor)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::APPLICATION_C Preferences;
      COLOR_C Color(0x11,0x22,0x55,0xAA);


      BOOST_CHECK(Preferences.GetBackgroundColor()==
          fc_DefaultTrayIconBackgroundColor);
      Preferences.SetBackgroundColor(Color);
      BOOST_CHECK(Preferences.GetAnimationPathname()==
          fc_pDefaultAnimationPathname);
      BOOST_CHECK(Preferences.GetBackgroundColor()==Color);
      BOOST_CHECK(Preferences.GetConfirmDiscardFlag()==
          fc_DefaultConfirmDiscardFlag);
      BOOST_CHECK(Preferences.GetConfirmQuitFlag()==
          fc_DefaultConfirmQuitFlag);
      BOOST_CHECK(Preferences.GetRemindOncePerSessionFlag()==
          fc_DefaultRemindOncePerSessionFlag);
      BOOST_CHECK(Preferences.GetStillRunningReminderFlag()==
          fc_DefaultStillRunningReminderFlag);
      BOOST_CHECK(Preferences.GetUnsavedChangesReminderFlag()==
          fc_DefaultUnsavedChangesReminderFlag);
      BOOST_CHECK(Preferences.GetUseOpaqueBackgroundFlag()==
          fc_DefaultUseOpaqueBackgroundFlag);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(
      Functions__GetConfirmDiscardFlag_SetConfirmDiscardFlag)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::APPLICATION_C Preferences;


      BOOST_CHECK(Preferences.GetConfirmDiscardFlag()==
          fc_DefaultConfirmDiscardFlag);
      Preferences.SetConfirmDiscardFlag(!fc_DefaultConfirmDiscardFlag);
      BOOST_CHECK(Preferences.GetAnimationPathname()==
          fc_pDefaultAnimationPathname);
      BOOST_CHECK(Preferences.GetBackgroundColor()==
          fc_DefaultTrayIconBackgroundColor);
      BOOST_CHECK(Preferences.GetConfirmDiscardFlag()==
          !fc_DefaultConfirmDiscardFlag);
      BOOST_CHECK(Preferences.GetConfirmQuitFlag()==
          fc_DefaultConfirmQuitFlag);
      BOOST_CHECK(Preferences.GetRemindOncePerSessionFlag()==
          fc_DefaultRemindOncePerSessionFlag);
      BOOST_CHECK(Preferences.GetStillRunningReminderFlag()==
          fc_DefaultStillRunningReminderFlag);
      BOOST_CHECK(Preferences.GetUnsavedChangesReminderFlag()==
          fc_DefaultUnsavedChangesReminderFlag);
      BOOST_CHECK(Preferences.GetUseOpaqueBackgroundFlag()==
          fc_DefaultUseOpaqueBackgroundFlag);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Functions__GetConfirmQuitFlag_SetConfirmQuitFlag)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::APPLICATION_C Preferences;


      BOOST_CHECK(Preferences.GetConfirmQuitFlag()==
          fc_DefaultConfirmQuitFlag);
      Preferences.SetConfirmQuitFlag(!fc_DefaultConfirmQuitFlag);
      BOOST_CHECK(Preferences.GetAnimationPathname()==
          fc_pDefaultAnimationPathname);
      BOOST_CHECK(Preferences.GetBackgroundColor()==
          fc_DefaultTrayIconBackgroundColor);
      BOOST_CHECK(Preferences.GetConfirmDiscardFlag()==
          fc_DefaultConfirmDiscardFlag);
      BOOST_CHECK(Preferences.GetConfirmQuitFlag()==
          !fc_DefaultConfirmQuitFlag);
      BOOST_CHECK(Preferences.GetRemindOncePerSessionFlag()==
          fc_DefaultRemindOncePerSessionFlag);
      BOOST_CHECK(Preferences.GetStillRunningReminderFlag()==
          fc_DefaultStillRunningReminderFlag);
      BOOST_CHECK(Preferences.GetUnsavedChangesReminderFlag()==
          fc_DefaultUnsavedChangesReminderFlag);
      BOOST_CHECK(Preferences.GetUseOpaqueBackgroundFlag()==
          fc_DefaultUseOpaqueBackgroundFlag);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(
      Functions__GetRemindOncePerSessionFlag_SetRemindOncePerSessionFlag)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::APPLICATION_C Preferences;


      BOOST_CHECK(Preferences.GetRemindOncePerSessionFlag()==
          fc_DefaultRemindOncePerSessionFlag);
      Preferences.SetRemindOncePerSessionFlag(
          !fc_DefaultRemindOncePerSessionFlag);
      BOOST_CHECK(Preferences.GetAnimationPathname()==
          fc_pDefaultAnimationPathname);
      BOOST_CHECK(Preferences.GetBackgroundColor()==
          fc_DefaultTrayIconBackgroundColor);
      BOOST_CHECK(Preferences.GetConfirmDiscardFlag()==
          fc_DefaultConfirmDiscardFlag);
      BOOST_CHECK(Preferences.GetConfirmQuitFlag()==
          fc_DefaultConfirmQuitFlag);
      BOOST_CHECK(Preferences.GetRemindOncePerSessionFlag()==
          !fc_DefaultRemindOncePerSessionFlag);
      BOOST_CHECK(Preferences.GetStillRunningReminderFlag()==
          fc_DefaultStillRunningReminderFlag);
      BOOST_CHECK(Preferences.GetUnsavedChangesReminderFlag()==
          fc_DefaultUnsavedChangesReminderFlag);
      BOOST_CHECK(Preferences.GetUseOpaqueBackgroundFlag()==
          fc_DefaultUseOpaqueBackgroundFlag);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(
      Functions__GetStillRunningReminderFlag_SetStillRunningReminderFlag)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::APPLICATION_C Preferences;


      BOOST_CHECK(Preferences.GetStillRunningReminderFlag()==
          fc_DefaultStillRunningReminderFlag);
      Preferences.SetStillRunningReminderFlag(
          !fc_DefaultStillRunningReminderFlag);
      BOOST_CHECK(Preferences.GetAnimationPathname()==
          fc_pDefaultAnimationPathname);
      BOOST_CHECK(Preferences.GetBackgroundColor()==
          fc_DefaultTrayIconBackgroundColor);
      BOOST_CHECK(Preferences.GetConfirmDiscardFlag()==
          fc_DefaultConfirmDiscardFlag);
      BOOST_CHECK(Preferences.GetConfirmQuitFlag()==
          fc_DefaultConfirmQuitFlag);
      BOOST_CHECK(Preferences.GetRemindOncePerSessionFlag()==
          fc_DefaultRemindOncePerSessionFlag);
      BOOST_CHECK(Preferences.GetStillRunningReminderFlag()==
          !fc_DefaultStillRunningReminderFlag);
      BOOST_CHECK(Preferences.GetUnsavedChangesReminderFlag()==
          fc_DefaultUnsavedChangesReminderFlag);
      BOOST_CHECK(Preferences.GetUseOpaqueBackgroundFlag()==
          fc_DefaultUseOpaqueBackgroundFlag);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(
      Functions__GetUnsavedChangesReminderFlag_SetUnsavedChangesReminderFlag)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::APPLICATION_C Preferences;


      BOOST_CHECK(Preferences.GetUnsavedChangesReminderFlag()==
          fc_DefaultUnsavedChangesReminderFlag);
      Preferences.SetUnsavedChangesReminderFlag(
          !fc_DefaultUnsavedChangesReminderFlag);
      BOOST_CHECK(Preferences.GetAnimationPathname()==
          fc_pDefaultAnimationPathname);
      BOOST_CHECK(Preferences.GetBackgroundColor()==
          fc_DefaultTrayIconBackgroundColor);
      BOOST_CHECK(Preferences.GetConfirmDiscardFlag()==
          fc_DefaultConfirmDiscardFlag);
      BOOST_CHECK(Preferences.GetConfirmQuitFlag()==
          fc_DefaultConfirmQuitFlag);
      BOOST_CHECK(Preferences.GetRemindOncePerSessionFlag()==
          fc_DefaultRemindOncePerSessionFlag);
      BOOST_CHECK(Preferences.GetStillRunningReminderFlag()==
          fc_DefaultStillRunningReminderFlag);
      BOOST_CHECK(Preferences.GetUnsavedChangesReminderFlag()==
          !fc_DefaultUnsavedChangesReminderFlag);
      BOOST_CHECK(Preferences.GetUseOpaqueBackgroundFlag()==
          fc_DefaultUseOpaqueBackgroundFlag);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(
      Functions__GetUseOpaqueBackgroundFlag_SetUseOpaqueBackgroundFlag)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::APPLICATION_C Preferences;


      BOOST_CHECK(Preferences.GetUseOpaqueBackgroundFlag()==
          fc_DefaultUseOpaqueBackgroundFlag);
      Preferences.SetUseOpaqueBackgroundFlag(
          !fc_DefaultUseOpaqueBackgroundFlag);
      BOOST_CHECK(Preferences.GetAnimationPathname()==
          fc_pDefaultAnimationPathname);
      BOOST_CHECK(Preferences.GetBackgroundColor()==
          fc_DefaultTrayIconBackgroundColor);
      BOOST_CHECK(Preferences.GetConfirmDiscardFlag()==
          fc_DefaultConfirmDiscardFlag);
      BOOST_CHECK(Preferences.GetConfirmQuitFlag()==
          fc_DefaultConfirmQuitFlag);
      BOOST_CHECK(Preferences.GetRemindOncePerSessionFlag()==
          fc_DefaultRemindOncePerSessionFlag);
      BOOST_CHECK(Preferences.GetStillRunningReminderFlag()==
          fc_DefaultStillRunningReminderFlag);
      BOOST_CHECK(Preferences.GetUnsavedChangesReminderFlag()==
          fc_DefaultUnsavedChangesReminderFlag);
      BOOST_CHECK(Preferences.GetUseOpaqueBackgroundFlag()==
          !fc_DefaultUseOpaqueBackgroundFlag);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Function__CopyConstructor)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::APPLICATION_C Preferences;


      Preferences.SetAnimationPathname("Pathname");
      Preferences.SetBackgroundColor(COLOR_C(0x33,0x44,0x55));
      Preferences.SetConfirmDiscardFlag(!fc_DefaultConfirmDiscardFlag);
      Preferences.SetConfirmQuitFlag(!fc_DefaultConfirmQuitFlag);
      Preferences.SetRemindOncePerSessionFlag(
          !fc_DefaultRemindOncePerSessionFlag);
      Preferences.SetStillRunningReminderFlag(
          !fc_DefaultStillRunningReminderFlag);
      Preferences.SetUnsavedChangesReminderFlag(
          !fc_DefaultUnsavedChangesReminderFlag);
      Preferences.SetUseOpaqueBackgroundFlag(
          !fc_DefaultUseOpaqueBackgroundFlag);

      PREFERENCES_C::APPLICATION_C Copy(Preferences);;

      BOOST_CHECK(Copy.GetUseOpaqueBackgroundFlag()==
          !fc_DefaultUseOpaqueBackgroundFlag);
      BOOST_CHECK(Copy.GetAnimationPathname()=="Pathname");
      BOOST_CHECK(Copy.GetBackgroundColor()==COLOR_C(0x33,0x44,0x55));
      BOOST_CHECK(Copy.GetConfirmDiscardFlag()==
          !fc_DefaultConfirmDiscardFlag);
      BOOST_CHECK(Copy.GetConfirmQuitFlag()==
          !fc_DefaultConfirmQuitFlag);
      BOOST_CHECK(Copy.GetRemindOncePerSessionFlag()==
          !fc_DefaultRemindOncePerSessionFlag);
      BOOST_CHECK(Copy.GetStillRunningReminderFlag()==
          !fc_DefaultStillRunningReminderFlag);
      BOOST_CHECK(Copy.GetUnsavedChangesReminderFlag()==
          !fc_DefaultUnsavedChangesReminderFlag);
      BOOST_CHECK(Copy.GetUseOpaqueBackgroundFlag()==
          !fc_DefaultUseOpaqueBackgroundFlag);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Function__CopyOperator)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::APPLICATION_C Preferences;
      PREFERENCES_C::APPLICATION_C Copy;


      Preferences.SetAnimationPathname("Pathname");
      Preferences.SetBackgroundColor(COLOR_C(0x66,0x77,0x88));
      Preferences.SetConfirmDiscardFlag(!fc_DefaultConfirmDiscardFlag);
      Preferences.SetConfirmQuitFlag(!fc_DefaultConfirmQuitFlag);
      Preferences.SetRemindOncePerSessionFlag(
          !fc_DefaultRemindOncePerSessionFlag);
      Preferences.SetStillRunningReminderFlag(
          !fc_DefaultStillRunningReminderFlag);
      Preferences.SetUnsavedChangesReminderFlag(
          !fc_DefaultUnsavedChangesReminderFlag);
      Preferences.SetUseOpaqueBackgroundFlag(
          !fc_DefaultUseOpaqueBackgroundFlag);

      Copy=Preferences;

      BOOST_CHECK(Copy.GetUseOpaqueBackgroundFlag()==
          !fc_DefaultUseOpaqueBackgroundFlag);
      BOOST_CHECK(Copy.GetAnimationPathname()=="Pathname");
      BOOST_CHECK(Copy.GetBackgroundColor()==COLOR_C(0x66,0x77,0x88));
      BOOST_CHECK(Copy.GetConfirmDiscardFlag()==
          !fc_DefaultConfirmDiscardFlag);
      BOOST_CHECK(Copy.GetConfirmQuitFlag()==
          !fc_DefaultConfirmQuitFlag);
      BOOST_CHECK(Copy.GetRemindOncePerSessionFlag()==
          !fc_DefaultRemindOncePerSessionFlag);
      BOOST_CHECK(Copy.GetStillRunningReminderFlag()==
          !fc_DefaultStillRunningReminderFlag);
      BOOST_CHECK(Copy.GetUnsavedChangesReminderFlag()==
          !fc_DefaultUnsavedChangesReminderFlag);
      BOOST_CHECK(Copy.GetUseOpaqueBackgroundFlag()==
          !fc_DefaultUseOpaqueBackgroundFlag);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      PREFERENCES_C::APPLICATION_C Preferences;
      PREFERENCES_C::APPLICATION_C &Copy=Preferences;


      Preferences.SetAnimationPathname("Pathname");
      Preferences.SetBackgroundColor(COLOR_C(0x66,0x77,0x88));
      Preferences.SetConfirmDiscardFlag(!fc_DefaultConfirmDiscardFlag);
      Preferences.SetConfirmQuitFlag(!fc_DefaultConfirmQuitFlag);
      Preferences.SetRemindOncePerSessionFlag(
          !fc_DefaultRemindOncePerSessionFlag);
      Preferences.SetStillRunningReminderFlag(
          !fc_DefaultStillRunningReminderFlag);
      Preferences.SetUnsavedChangesReminderFlag(
          !fc_DefaultUnsavedChangesReminderFlag);
      Preferences.SetUseOpaqueBackgroundFlag(
          !fc_DefaultUseOpaqueBackgroundFlag);

      Copy=Preferences;

      BOOST_CHECK(Copy.GetUseOpaqueBackgroundFlag()==
          !fc_DefaultUseOpaqueBackgroundFlag);
      BOOST_CHECK(Copy.GetAnimationPathname()=="Pathname");
      BOOST_CHECK(Copy.GetBackgroundColor()==COLOR_C(0x66,0x77,0x88));
      BOOST_CHECK(Copy.GetConfirmDiscardFlag()==
          !fc_DefaultConfirmDiscardFlag);
      BOOST_CHECK(Copy.GetConfirmQuitFlag()==
          !fc_DefaultConfirmQuitFlag);
      BOOST_CHECK(Copy.GetRemindOncePerSessionFlag()==
          !fc_DefaultRemindOncePerSessionFlag);
      BOOST_CHECK(Copy.GetStillRunningReminderFlag()==
          !fc_DefaultStillRunningReminderFlag);
      BOOST_CHECK(Copy.GetUnsavedChangesReminderFlag()==
          !fc_DefaultUnsavedChangesReminderFlag);
      BOOST_CHECK(Copy.GetUseOpaqueBackgroundFlag()==
          !fc_DefaultUseOpaqueBackgroundFlag);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Functions__EqualityOperator_InequalityOperator)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::APPLICATION_C Preferences0;
      PREFERENCES_C::APPLICATION_C Preferences1;


      for(int Index=0;Index<f_EqualityOperatorTestCaseCount;Index++)
      {
        InitializeApplicationValues(
            &f_pEqualityOperatorTestCases[Index].Preferences0,Preferences0);
        InitializeApplicationValues(
            &f_pEqualityOperatorTestCases[Index].Preferences1,Preferences1);

        BOOST_CHECK((Preferences0==Preferences1)==
            f_pEqualityOperatorTestCases[Index].Equal);
        BOOST_CHECK((Preferences0!=Preferences1)==
            !f_pEqualityOperatorTestCases[Index].Equal);
      }
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Function__Load)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::APPLICATION_C Preferences;


      for(int Index=0;Index<f_LoadTestCaseCount;Index++)
      {
      try
      {
        std::string String;
        COLOR_C Color;
        bool Bool;


        PreferencesManagerStub_SetPreference(fc_pAGAnimationPathnameKey,
            f_pLoadTestCases[Index].Values.AnimationPathname);
        PreferencesManagerStub_SetPreference(fc_pAGBackgroundColor,
            f_pLoadTestCases[Index].Values.BackgroundColor);
        PreferencesManagerStub_SetPreference(fc_pAGConfirmDiscardChangesKey,
            f_pLoadTestCases[Index].Values.ConfirmDiscardFlag);
        PreferencesManagerStub_SetPreference(fc_pAGConfirmQuitFlagKey,
            f_pLoadTestCases[Index].Values.ConfirmQuitFlag);
        PreferencesManagerStub_SetPreference(fc_pAGRemindOncePerSessionKey,
            f_pLoadTestCases[Index].Values.RemindOncePerSessionFlag);
        PreferencesManagerStub_SetPreference(fc_pAGStillRunningReminderKey,
            f_pLoadTestCases[Index].Values.StillRunningReminderFlag);
        PreferencesManagerStub_SetPreference(fc_pAGUnsavedChangesReminderKey,
            f_pLoadTestCases[Index].Values.UnsavedChangesReminderFlag);
        PreferencesManagerStub_SetPreference(fc_pAGUseOpaqueBackgroundKey,
            f_pLoadTestCases[Index].Values.UseOpaqueBackgroundFlag);

        Preferences.Load();

        std::vector<std::string> GroupList={fc_pApplicationGroupKey};
        BOOST_CHECK(PreferencesManagerStub_GetGroupList()==GroupList);
        PreferencesManagerStub_GetPreference(
            fc_pAGAnimationPathnameKey,String);
        BOOST_CHECK(String==f_pLoadTestCases[Index].Values.AnimationPathname);
        PreferencesManagerStub_GetPreference(fc_pAGBackgroundColor,Color);
        BOOST_CHECK(Color==f_pLoadTestCases[Index].Values.BackgroundColor);
        PreferencesManagerStub_GetPreference(
            fc_pAGConfirmDiscardChangesKey,Bool);
        BOOST_CHECK(Bool==f_pLoadTestCases[Index].Values.ConfirmDiscardFlag);
        PreferencesManagerStub_GetPreference(fc_pAGConfirmQuitFlagKey,Bool);
        BOOST_CHECK(Bool==f_pLoadTestCases[Index].Values.ConfirmQuitFlag);
        PreferencesManagerStub_GetPreference(
            fc_pAGRemindOncePerSessionKey,Bool);
        BOOST_CHECK(
            Bool==f_pLoadTestCases[Index].Values.RemindOncePerSessionFlag);
        PreferencesManagerStub_GetPreference(
            fc_pAGStillRunningReminderKey,Bool);
        BOOST_CHECK(
            Bool==f_pLoadTestCases[Index].Values.StillRunningReminderFlag);
        PreferencesManagerStub_GetPreference(
            fc_pAGUnsavedChangesReminderKey,Bool);
        BOOST_CHECK(
            Bool==f_pLoadTestCases[Index].Values.UnsavedChangesReminderFlag);
        PreferencesManagerStub_GetPreference(
            fc_pAGUseOpaqueBackgroundKey,Bool);
        BOOST_CHECK(
            Bool==f_pLoadTestCases[Index].Values.UseOpaqueBackgroundFlag);

        PreferencesManagerStub_ClearPreferences();
      }
      catch(...)
      {
        BOOST_CHECK(false);
      }
      }
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Function__Save)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::APPLICATION_C Preferences;


      for(int Index=0;Index<f_SaveTestCaseCount;Index++)
      {
      try
      {
        std::string String;
        COLOR_C Color;
        bool Bool;


        InitializeApplicationValues(&f_pSaveTestCases[Index].Values,Preferences);

        Preferences.Save();

        std::vector<std::string> GroupList={fc_pApplicationGroupKey};
        BOOST_CHECK(PreferencesManagerStub_GetGroupList()==GroupList);
        PreferencesManagerStub_GetPreference(
            fc_pAGAnimationPathnameKey,String);
        BOOST_CHECK(String==f_pSaveTestCases[Index].Values.AnimationPathname);
        PreferencesManagerStub_GetPreference(
            fc_pAGBackgroundColor,Color);
        BOOST_CHECK(Color==f_pSaveTestCases[Index].Values.BackgroundColor);
        PreferencesManagerStub_GetPreference(
            fc_pAGConfirmDiscardChangesKey,Bool);
        BOOST_CHECK(Bool==f_pSaveTestCases[Index].Values.ConfirmDiscardFlag);
        PreferencesManagerStub_GetPreference(
            fc_pAGConfirmQuitFlagKey,Bool);
        BOOST_CHECK(Bool==f_pSaveTestCases[Index].Values.ConfirmQuitFlag);
        PreferencesManagerStub_GetPreference(
            fc_pAGRemindOncePerSessionKey,Bool);
        BOOST_CHECK(Bool==
            f_pSaveTestCases[Index].Values.RemindOncePerSessionFlag);
        PreferencesManagerStub_GetPreference(
            fc_pAGStillRunningReminderKey,Bool);
        BOOST_CHECK(Bool==
            f_pSaveTestCases[Index].Values.StillRunningReminderFlag);
        PreferencesManagerStub_GetPreference(
            fc_pAGUnsavedChangesReminderKey,Bool);
        BOOST_CHECK(Bool==
            f_pSaveTestCases[Index].Values.UnsavedChangesReminderFlag);
        PreferencesManagerStub_GetPreference(
            fc_pAGUseOpaqueBackgroundKey,Bool);
        BOOST_CHECK(Bool==
            f_pSaveTestCases[Index].Values.UseOpaqueBackgroundFlag);

        PreferencesManagerStub_ClearPreferences();
      }
      catch(...)
      {
        BOOST_CHECK(false);
      }
      }
    }
  BOOST_AUTO_TEST_SUITE_END()
BOOST_AUTO_TEST_SUITE_END()


#undef    PREFERENCES_TEST_PREFERENCES_APPLICATION_CPP


/**
*** preferences_test_preferences_application.cpp
**/
