/**
*** \file preferences_test_preferences_moondata_options.cpp
*** \brief Class 'PREFERENCES_C::MOONDATA_C::OPTIONS_C' unit test file.
*** \details Unit test file for the 'PREFERENCES_C::MOONDATA_C::OPTIONS_C' class.
**/

/*
** This file is part of moonphase.
** Copyright (C) 2014-2023 Alan Wise <awisesoftware@gmail.com>.
**
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation, either version 3 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/


/**
*** \internal
*** \brief preferences_test_preferences_moondata_options.cpp identifier.
*** \details Identifier for preferences_test_preferences_moondata_options.cpp.
*** \endinternal
**/
#define   PREFERENCES_TEST_PREFERENCES_MOONDATA_OPTIONS_CPP


/****
*****
***** INCLUDES
*****
****/


/****
*****
***** DEFINES
*****
****/


/****
*****
***** DATA TYPES
*****
****/

typedef struct
{
  bool DefaultToGMTFlag;
  bool DefaultToMetricUnitsFlag;
  double Latitude;
  double Longitude;
} OPTIONVALUES_T;


/****
*****
***** CLASSES
*****
****/


/****
*****
***** PROTOTYPES
*****
****/


/****
*****
***** DATA
*****
****/

struct
{
  OPTIONVALUES_T Preferences0;
  OPTIONVALUES_T Preferences1;
  bool Equal;
} static const f_pOptionEqualityOperatorTestCases[]=
{
  /* 'true' return. */
  {
    /* GMT   Met   Lat Lon */
    {  false,false,0.0,0.0 },
    {  false,false,0.0,0.0 },
    true
  },
  /* Cycle false through the boolean 'ands'. */
  {
    /* GMT   Met   Lat Lon */
    {   true,false,0.0,0.0 },
    {  false,false,0.0,0.0 },
    false
  },
  {
    /* GMT   Met   Lat Lon */
    {  false, true,0.0,0.0 },
    {  false,false,0.0,0.0 },
    false
  },
  {
    /* GMT   Met   Lat Lon */
    {  false,false,1.0,0.0 },
    {  false,false,0.0,0.0 },
    false
  },
  {
    /* GMT   Met   Lat Lon */
    {  false,false,0.0,1.0 },
    {  false,false,0.0,0.0 },
    false
  },
  {
    /* GMT   Met   Lat Lon */
    {  false,false,0.0,0.0 },
    {   true,false,0.0,0.0 },
    false
  },
  {
    /* GMT   Met   Lat Lon */
    {  false,false,0.0,0.0 },
    {  false, true,0.0,0.0 },
    false
  },
  {
    /* GMT   Met   Lat Lon */
    {  false,false,0.0,0.0 },
    {  false,false,1.0,0.0 },
    false
  },
  {
    /* GMT   Met   Lat Lon */
    {  false,false,0.0,0.0 },
    {  false,false,0.0,1.0 },
    false
  }
};
static int const f_OptionEqualityOperatorTestCaseCount=
    sizeof(f_pOptionEqualityOperatorTestCases)/
    sizeof(*f_pOptionEqualityOperatorTestCases);


/****
*****
***** VARIABLES
*****
****/


/****
*****
***** FUNCTIONS
*****
****/

static void InitializeOptionValues(OPTIONVALUES_T const *pInitialValues,
    PREFERENCES_C::MOONDATA_C::OPTIONS_C &Preferences)
{
  if (pInitialValues==nullptr)
    throw(std::invalid_argument("pInitialValues==nullptr"));

  Preferences.SetDefaultToGMTFlag(pInitialValues->DefaultToGMTFlag);
  Preferences.SetDefaultToMetricUnitsFlag(
      pInitialValues->DefaultToMetricUnitsFlag);
  Preferences.SetLatitude(pInitialValues->Latitude);
  Preferences.SetLongitude(pInitialValues->Longitude);

  return;
}


/****
*****
***** TESTS
*****
****/

BOOST_AUTO_TEST_SUITE(Class__PREFERENCES_MOONDATA_OPTIONS)
  BOOST_AUTO_TEST_SUITE(Function__DefaultConstructor)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      std::unique_ptr<PREFERENCES_C::MOONDATA_C::OPTIONS_C> pPreferences;


      pPreferences.reset(new PREFERENCES_C::MOONDATA_C::OPTIONS_C());

      BOOST_CHECK(pPreferences.get()!=nullptr);
      BOOST_CHECK(pPreferences->GetDefaultToGMTFlag()==
          fc_DefaultDefaultToGMTFlag);
      BOOST_CHECK(pPreferences->GetDefaultToMetricUnitsFlag()==
          fc_DefaultDefaultToMetricUnitsFlag);
      BOOST_CHECK(pPreferences->GetLatitude()==fc_DefaultLatitude);
      BOOST_CHECK(pPreferences->GetLongitude()==fc_DefaultLongitude);

      delete pPreferences.release();
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Function__CopyConstructor)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences0;


      Preferences0.SetDefaultToGMTFlag(!fc_DefaultDefaultToGMTFlag);
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences1(Preferences0);
      BOOST_CHECK(Preferences1.GetDefaultToGMTFlag()==
          !fc_DefaultDefaultToGMTFlag);
      BOOST_CHECK(Preferences1.GetDefaultToMetricUnitsFlag()==
          fc_DefaultDefaultToMetricUnitsFlag);
      BOOST_CHECK(Preferences1.GetLatitude()==fc_DefaultLatitude);
      BOOST_CHECK(Preferences1.GetLongitude()==fc_DefaultLongitude);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences0;


      Preferences0.SetDefaultToMetricUnitsFlag(
          !fc_DefaultDefaultToMetricUnitsFlag);
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences1(Preferences0);
      BOOST_CHECK(Preferences1.GetDefaultToGMTFlag()==
          fc_DefaultDefaultToGMTFlag);
      BOOST_CHECK(Preferences1.GetDefaultToMetricUnitsFlag()==
          !fc_DefaultDefaultToMetricUnitsFlag);
      BOOST_CHECK(Preferences1.GetLatitude()==fc_DefaultLatitude);
      BOOST_CHECK(Preferences1.GetLongitude()==fc_DefaultLongitude);
    }
    BOOST_AUTO_TEST_CASE(Test_02)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences0;


      Preferences0.SetLatitude(2048.0);
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences1(Preferences0);
      BOOST_CHECK(Preferences1.GetDefaultToGMTFlag()==
          fc_DefaultDefaultToGMTFlag);
      BOOST_CHECK(Preferences1.GetDefaultToMetricUnitsFlag()==
          fc_DefaultDefaultToMetricUnitsFlag);
      BOOST_CHECK(Preferences1.GetLatitude()==2048.0);
      BOOST_CHECK(Preferences1.GetLongitude()==fc_DefaultLongitude);
    }
    BOOST_AUTO_TEST_CASE(Test_03)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences0;


      Preferences0.SetLongitude(8192.0);
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences1(Preferences0);
      BOOST_CHECK(Preferences1.GetDefaultToGMTFlag()==
          fc_DefaultDefaultToGMTFlag);
      BOOST_CHECK(Preferences1.GetDefaultToMetricUnitsFlag()==
          fc_DefaultDefaultToMetricUnitsFlag);
      BOOST_CHECK(Preferences1.GetLatitude()==fc_DefaultLatitude);
      BOOST_CHECK(Preferences1.GetLongitude()==8192.0);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Function__CopyOperator)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences0;
      PREFERENCES_C::MOONDATA_C::OPTIONS_C &Preferences1=Preferences0;


      Preferences1=Preferences0;
      BOOST_CHECK(Preferences1.GetDefaultToGMTFlag()==
          fc_DefaultDefaultToGMTFlag);
      BOOST_CHECK(Preferences1.GetDefaultToMetricUnitsFlag()==
          fc_DefaultDefaultToMetricUnitsFlag);
      BOOST_CHECK(Preferences1.GetLatitude()==fc_DefaultLatitude);
      BOOST_CHECK(Preferences1.GetLongitude()==fc_DefaultLongitude);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences0;
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences1;


      Preferences0.SetDefaultToGMTFlag(!fc_DefaultDefaultToGMTFlag);
      Preferences1=Preferences0;
      BOOST_CHECK(Preferences1.GetDefaultToGMTFlag()==
          !fc_DefaultDefaultToGMTFlag);
      BOOST_CHECK(Preferences1.GetDefaultToMetricUnitsFlag()==
          fc_DefaultDefaultToMetricUnitsFlag);
      BOOST_CHECK(Preferences1.GetLatitude()==fc_DefaultLatitude);
      BOOST_CHECK(Preferences1.GetLongitude()==fc_DefaultLongitude);
    }
    BOOST_AUTO_TEST_CASE(Test_02)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences0;
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences1;


      Preferences0.SetDefaultToMetricUnitsFlag(
          !fc_DefaultDefaultToMetricUnitsFlag);
      Preferences1=Preferences0;
      BOOST_CHECK(Preferences1.GetDefaultToGMTFlag()==
          fc_DefaultDefaultToGMTFlag);
      BOOST_CHECK(Preferences1.GetDefaultToMetricUnitsFlag()==
          !fc_DefaultDefaultToMetricUnitsFlag);
      BOOST_CHECK(Preferences1.GetLatitude()==fc_DefaultLatitude);
      BOOST_CHECK(Preferences1.GetLongitude()==fc_DefaultLongitude);
    }
    BOOST_AUTO_TEST_CASE(Test_03)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences0;
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences1;


      Preferences0.SetLatitude(12288.0);
      Preferences1=Preferences0;
      BOOST_CHECK(Preferences1.GetDefaultToGMTFlag()==
          fc_DefaultDefaultToGMTFlag);
      BOOST_CHECK(Preferences1.GetDefaultToMetricUnitsFlag()==
          fc_DefaultDefaultToMetricUnitsFlag);
      BOOST_CHECK(Preferences1.GetLatitude()==12288.0);
      BOOST_CHECK(Preferences1.GetLongitude()==fc_DefaultLongitude);
    }
    BOOST_AUTO_TEST_CASE(Test_04)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences0;
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences1;


      Preferences0.SetLatitude(16384.0);
      Preferences1=Preferences0;
      BOOST_CHECK(Preferences1.GetDefaultToGMTFlag()==
          fc_DefaultDefaultToGMTFlag);
      BOOST_CHECK(Preferences1.GetDefaultToMetricUnitsFlag()==
          fc_DefaultDefaultToMetricUnitsFlag);
      BOOST_CHECK(Preferences1.GetLatitude()==16384.0);
      BOOST_CHECK(Preferences1.GetLongitude()==fc_DefaultLongitude);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_AUTO_TEST_SUITE(Function__EqualityOperator_InequalityOperator)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences0;
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences1;


      for(int Index=0;Index<f_OptionEqualityOperatorTestCaseCount;Index++)
      {
        try
        {
          InitializeOptionValues(
              &f_pOptionEqualityOperatorTestCases[Index].Preferences0,
              Preferences0);
          InitializeOptionValues(
              &f_pOptionEqualityOperatorTestCases[Index].Preferences1,
              Preferences1);
          BOOST_CHECK((Preferences0==Preferences1)==
              f_pOptionEqualityOperatorTestCases[Index].Equal);
          BOOST_CHECK((Preferences0!=Preferences1)==
              !f_pOptionEqualityOperatorTestCases[Index].Equal);
        }
        catch(...)
        {
          BOOST_CHECK(false);
        }
      }
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_AUTO_TEST_SUITE(Function__GetDefaultToGMTFlag_SetDefaultToGMTFlag)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences;


      BOOST_CHECK(Preferences.GetDefaultToGMTFlag()==
          fc_DefaultDefaultToGMTFlag);
      Preferences.SetDefaultToGMTFlag(!fc_DefaultDefaultToGMTFlag);
      BOOST_CHECK(Preferences.GetDefaultToGMTFlag()==
          !fc_DefaultDefaultToGMTFlag);
      BOOST_CHECK(Preferences.GetDefaultToMetricUnitsFlag()==
          fc_DefaultDefaultToMetricUnitsFlag);
      BOOST_CHECK(Preferences.GetLatitude()==fc_DefaultLatitude);
      BOOST_CHECK(Preferences.GetLongitude()==fc_DefaultLongitude);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(
      Function__GetDefaultToMetricUnitsFlag_SetDefaultToMetricUnitsFlag)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences;


      BOOST_CHECK(Preferences.GetDefaultToMetricUnitsFlag()==
          fc_DefaultDefaultToMetricUnitsFlag);
      Preferences.SetDefaultToMetricUnitsFlag(
          !fc_DefaultDefaultToMetricUnitsFlag);
      BOOST_CHECK(Preferences.GetDefaultToGMTFlag()==
          fc_DefaultDefaultToGMTFlag);
      BOOST_CHECK(Preferences.GetDefaultToMetricUnitsFlag()==
          !fc_DefaultDefaultToMetricUnitsFlag);
      BOOST_CHECK(Preferences.GetLatitude()==fc_DefaultLatitude);
      BOOST_CHECK(Preferences.GetLongitude()==fc_DefaultLongitude);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Function__GetLatitude_SetLatitude)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences;


      BOOST_CHECK(Preferences.GetLatitude()==fc_DefaultLatitude);
      Preferences.SetLatitude(1024.0);
      BOOST_CHECK(Preferences.GetDefaultToGMTFlag()==
          fc_DefaultDefaultToGMTFlag);
      BOOST_CHECK(Preferences.GetDefaultToMetricUnitsFlag()==
          fc_DefaultDefaultToMetricUnitsFlag);
      BOOST_CHECK(Preferences.GetLatitude()==1024.0);
      BOOST_CHECK(Preferences.GetLongitude()==fc_DefaultLongitude);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Function__GetLongitude_SetLongitude)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences;


      BOOST_CHECK(Preferences.GetLongitude()==fc_DefaultLongitude);
      Preferences.SetLongitude(1536.0);
      BOOST_CHECK(Preferences.GetDefaultToGMTFlag()==
          fc_DefaultDefaultToGMTFlag);
      BOOST_CHECK(Preferences.GetDefaultToMetricUnitsFlag()==
          fc_DefaultDefaultToMetricUnitsFlag);
      BOOST_CHECK(Preferences.GetLatitude()==fc_DefaultLatitude);
      BOOST_CHECK(Preferences.GetLongitude()==1536.0);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Function__Load)
    BOOST_AUTO_TEST_CASE_EXPECTED_FAILURES(Test_00,1)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences;


      Preferences.Load();
      BOOST_CHECK(false);
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Function__Save)
    BOOST_AUTO_TEST_CASE_EXPECTED_FAILURES(Test_00,1)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::MOONDATA_C::OPTIONS_C Preferences;


      Preferences.Save();
      BOOST_CHECK(false);
    }
  BOOST_AUTO_TEST_SUITE_END()
BOOST_AUTO_TEST_SUITE_END()


#undef    PREFERENCES_TEST_PREFERENCES_MOONDATA_OPTIONS_CPP


/**
*** preferences_test_preferences_moondata_options.cpp
**/
