/**
*** \file preferences_test_preferences_moondata_panel_display.cpp
*** \brief Class 'PREFERENCES_C::MOONDATA_C::PANEL_C::DISPLAY_C' unit test file.
*** \details Unit test file for the
***   'PREFERENCES_C::MOONDATA_C::PANEL_C::DISPLAY_C' class.
**/

/*
** This file is part of moonphase.
** Copyright (C) 2014-2023 Alan Wise <awisesoftware@gmail.com>.
**
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation, either version 3 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/


/**
*** \internal
*** \brief preferences_test_preferences_moondata_panel_display.cpp identifier.
*** \details Identifier for
***   preferences_test_preferences_moondata_panel_display.cpp.
*** \endinternal
**/
#define   PREFERENCES_TEST_PREFERENCES__MOONDATA_PANEL_DISPLAY_CPP


/****
*****
***** INCLUDES
*****
****/


/****
*****
***** DEFINES
*****
****/


/****
*****
***** DATA TYPES
*****
****/

namespace DISPLAY
{
  typedef struct
  {
    bool AlwaysOnTopFlag;
    bool DisplayOnStartUpFlag;
    bool HideCloseButtonFlag;
    bool KeepOnScreenFlag;
    POSITION_C Position;
    SIZE_C Size;
  } VALUES_T;
}


/****
*****
***** CLASSES
*****
****/


/****
*****
***** PROTOTYPES
*****
****/


/****
*****
***** DATA
*****
****/

namespace DISPLAY
{
  static VALUES_T const f_pCopyConstructorTestCases[]=
  {
    /* Cycle non-default values through constructor. */
    {
      !f_DefaultAlwaysOnTopFlag,f_DefaultDisplayOnStartUpFlag,
      f_DefaultHideCloseButtonFlag,f_DefaultKeepOnScreenFlag,
      POSITION_C(),SIZE_C()
    },
    {
      f_DefaultAlwaysOnTopFlag,!f_DefaultDisplayOnStartUpFlag,
      f_DefaultHideCloseButtonFlag,f_DefaultKeepOnScreenFlag,
      POSITION_C(),SIZE_C()
    },
    {
      f_DefaultAlwaysOnTopFlag,f_DefaultDisplayOnStartUpFlag,
      !f_DefaultHideCloseButtonFlag,f_DefaultKeepOnScreenFlag,
      POSITION_C(),SIZE_C()
    },
    {
      f_DefaultAlwaysOnTopFlag,f_DefaultDisplayOnStartUpFlag,
      f_DefaultHideCloseButtonFlag,!f_DefaultKeepOnScreenFlag,
      POSITION_C(),SIZE_C()
    },
    {
      f_DefaultAlwaysOnTopFlag,f_DefaultDisplayOnStartUpFlag,
      f_DefaultHideCloseButtonFlag,f_DefaultKeepOnScreenFlag,
      POSITION_C(3,13),SIZE_C()
    },
    {
      f_DefaultAlwaysOnTopFlag,f_DefaultDisplayOnStartUpFlag,
      f_DefaultHideCloseButtonFlag,f_DefaultKeepOnScreenFlag,
      POSITION_C(),SIZE_C(5,11)
    }
  };
  static int const f_CopyConstructorTestCaseCount=
    sizeof(f_pCopyConstructorTestCases)/sizeof(*f_pCopyConstructorTestCases);
}



/****
*****
***** VARIABLES
*****
****/


/****
*****
***** FUNCTIONS
*****
****/

namespace DISPLAY
{
  void InitializeValues(VALUES_T const *pValues,
      PREFERENCES_C::MOONDATA_C::PANEL_C::DISPLAY_C &Display)
  {
    Display.SetAlwaysOnTopFlag(pValues->AlwaysOnTopFlag);
    Display.SetDisplayOnStartUpFlag(pValues->DisplayOnStartUpFlag);
    Display.SetHideCloseButtonFlag(pValues->HideCloseButtonFlag);
    Display.SetKeepOnScreenFlag(pValues->KeepOnScreenFlag);
    Display.SetPosition(pValues->Position);
    Display.SetSize(pValues->Size);

    return;
  }
  void CheckValues(VALUES_T const *pValues,
      PREFERENCES_C::MOONDATA_C::PANEL_C::DISPLAY_C &Display)
  {
    BOOST_CHECK(Display.GetAlwaysOnTopFlag()==pValues->AlwaysOnTopFlag);
    BOOST_CHECK(
        Display.GetDisplayOnStartUpFlag()==pValues->DisplayOnStartUpFlag);
    BOOST_CHECK(Display.GetHideCloseButtonFlag()==pValues->HideCloseButtonFlag);
    BOOST_CHECK(Display.GetKeepOnScreenFlag()==pValues->KeepOnScreenFlag);
    BOOST_CHECK(Display.GetPosition()==pValues->Position);
    BOOST_CHECK(Display.GetSize()==pValues->Size);

    return;
  }
}


/****
*****
***** TESTS
*****
****/

BOOST_AUTO_TEST_SUITE(Class__PREFERENCES_MOONDATA_PANEL_DISPLAY)
  BOOST_AUTO_TEST_SUITE(Function__DefaultConstructor)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      std::unique_ptr<PREFERENCES_C::MOONDATA_C::PANEL_C::DISPLAY_C>
          pPreferences;


      pPreferences.reset(
          new PREFERENCES_C::MOONDATA_C::PANEL_C::DISPLAY_C());

      BOOST_CHECK(pPreferences.get()!=nullptr);
      BOOST_CHECK(pPreferences->GetAlwaysOnTopFlag()==
          f_DefaultAlwaysOnTopFlag);
      BOOST_CHECK(pPreferences->GetDisplayOnStartUpFlag()==
          f_DefaultDisplayOnStartUpFlag);
      BOOST_CHECK(pPreferences->GetHideCloseButtonFlag()==
          f_DefaultHideCloseButtonFlag);
      BOOST_CHECK(pPreferences->GetKeepOnScreenFlag()==
          f_DefaultKeepOnScreenFlag);
      BOOST_CHECK(pPreferences->GetPosition()==POSITION_C());
      BOOST_CHECK(pPreferences->GetSize()==SIZE_C());

      delete pPreferences.release();
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Functions__GetAlwaysOnTopFlag_SetAlwaysOnTopFlag)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::MOONDATA_C::PANEL_C::DISPLAY_C Preferences;


      BOOST_CHECK(Preferences.GetAlwaysOnTopFlag()==f_DefaultAlwaysOnTopFlag);
      Preferences.SetAlwaysOnTopFlag(!f_DefaultAlwaysOnTopFlag);
      BOOST_CHECK(Preferences.GetAlwaysOnTopFlag()==!f_DefaultAlwaysOnTopFlag);
      BOOST_CHECK(Preferences.GetDisplayOnStartUpFlag()==
          f_DefaultDisplayOnStartUpFlag);
      BOOST_CHECK(Preferences.GetHideCloseButtonFlag()==
          f_DefaultHideCloseButtonFlag);
      BOOST_CHECK(Preferences.GetKeepOnScreenFlag()==
          f_DefaultKeepOnScreenFlag);
      BOOST_CHECK(Preferences.GetPosition()==POSITION_C());
      BOOST_CHECK(Preferences.GetSize()==SIZE_C());
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(
      Functions__GetDisplayOnStartUpFlag_SetDisplayOnStartUpFlag)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::MOONDATA_C::PANEL_C::DISPLAY_C Preferences;


      BOOST_CHECK(Preferences.GetDisplayOnStartUpFlag()==
          f_DefaultDisplayOnStartUpFlag);
      Preferences.SetDisplayOnStartUpFlag(!f_DefaultDisplayOnStartUpFlag);
      BOOST_CHECK(Preferences.GetAlwaysOnTopFlag()==f_DefaultAlwaysOnTopFlag);
      BOOST_CHECK(Preferences.GetDisplayOnStartUpFlag()==
          !f_DefaultDisplayOnStartUpFlag);
      BOOST_CHECK(Preferences.GetHideCloseButtonFlag()==
          f_DefaultHideCloseButtonFlag);
      BOOST_CHECK(Preferences.GetKeepOnScreenFlag()==
          f_DefaultKeepOnScreenFlag);
      BOOST_CHECK(Preferences.GetPosition()==POSITION_C());
      BOOST_CHECK(Preferences.GetSize()==SIZE_C());
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(
      Functions__GetHideCloseButtonFlag_SetHideCloseButtonFlag)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::MOONDATA_C::PANEL_C::DISPLAY_C Preferences;


      BOOST_CHECK(Preferences.GetHideCloseButtonFlag()==
          f_DefaultHideCloseButtonFlag);
      Preferences.SetHideCloseButtonFlag(!f_DefaultHideCloseButtonFlag);
      BOOST_CHECK(Preferences.GetAlwaysOnTopFlag()==f_DefaultAlwaysOnTopFlag);
      BOOST_CHECK(Preferences.GetDisplayOnStartUpFlag()==
          f_DefaultDisplayOnStartUpFlag);
      BOOST_CHECK(Preferences.GetHideCloseButtonFlag()==
          !f_DefaultHideCloseButtonFlag);
      BOOST_CHECK(Preferences.GetKeepOnScreenFlag()==
          f_DefaultKeepOnScreenFlag);
      BOOST_CHECK(Preferences.GetPosition()==POSITION_C());
      BOOST_CHECK(Preferences.GetSize()==SIZE_C());
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(
      Functions__GetKeepOnScreenFlag_SetKeepOnScreenFlag)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::MOONDATA_C::PANEL_C::DISPLAY_C Preferences;


      BOOST_CHECK(Preferences.GetKeepOnScreenFlag()==
          f_DefaultKeepOnScreenFlag);
      Preferences.SetKeepOnScreenFlag(!f_DefaultKeepOnScreenFlag);
      BOOST_CHECK(Preferences.GetAlwaysOnTopFlag()==f_DefaultAlwaysOnTopFlag);
      BOOST_CHECK(Preferences.GetDisplayOnStartUpFlag()==
          f_DefaultDisplayOnStartUpFlag);
      BOOST_CHECK(Preferences.GetHideCloseButtonFlag()==
          f_DefaultHideCloseButtonFlag);
      BOOST_CHECK(Preferences.GetKeepOnScreenFlag()==
          !f_DefaultKeepOnScreenFlag);
      BOOST_CHECK(Preferences.GetPosition()==POSITION_C());
      BOOST_CHECK(Preferences.GetSize()==SIZE_C());
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Functions__GetPosition_SetPosition)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::MOONDATA_C::PANEL_C::DISPLAY_C Preferences;


      BOOST_CHECK(Preferences.GetPosition()==POSITION_C());
      Preferences.SetPosition(POSITION_C(5,7));
      BOOST_CHECK(Preferences.GetAlwaysOnTopFlag()==f_DefaultAlwaysOnTopFlag);
      BOOST_CHECK(Preferences.GetDisplayOnStartUpFlag()==
          f_DefaultDisplayOnStartUpFlag);
      BOOST_CHECK(Preferences.GetHideCloseButtonFlag()==
          f_DefaultHideCloseButtonFlag);
      BOOST_CHECK(Preferences.GetKeepOnScreenFlag()==
          f_DefaultKeepOnScreenFlag);
      BOOST_CHECK(Preferences.GetPosition()==POSITION_C(5,7));
      BOOST_CHECK(Preferences.GetSize()==SIZE_C());
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Functions__GetSize_SetSize)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCES_C::MOONDATA_C::PANEL_C::DISPLAY_C Preferences;


      BOOST_CHECK(Preferences.GetSize()==SIZE_C());
      Preferences.SetSize(SIZE_C(11,13));
      BOOST_CHECK(Preferences.GetAlwaysOnTopFlag()==f_DefaultAlwaysOnTopFlag);
      BOOST_CHECK(Preferences.GetDisplayOnStartUpFlag()==
          f_DefaultDisplayOnStartUpFlag);
      BOOST_CHECK(Preferences.GetHideCloseButtonFlag()==
          f_DefaultHideCloseButtonFlag);
      BOOST_CHECK(Preferences.GetKeepOnScreenFlag()==
          f_DefaultKeepOnScreenFlag);
      BOOST_CHECK(Preferences.GetPosition()==POSITION_C());
      BOOST_CHECK(Preferences.GetSize()==SIZE_C(11,13));
    }
  BOOST_AUTO_TEST_SUITE_END()
  BOOST_AUTO_TEST_SUITE(Functions__CopyConstructor)
//    BOOST_AUTO_TEST_CASE(Test_00) check self assignment
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      for(int Index=0;Index<DISPLAY::f_CopyConstructorTestCaseCount;Index++)
      {
        PREFERENCES_C::MOONDATA_C::PANEL_C::DISPLAY_C Preferences0;


        DISPLAY::InitializeValues(
            &DISPLAY::f_pCopyConstructorTestCases[Index],Preferences0);
        PREFERENCES_C::MOONDATA_C::PANEL_C::DISPLAY_C Preferences1(Preferences0);
        DISPLAY::CheckValues(
            &DISPLAY::f_pCopyConstructorTestCases[Index],Preferences1);
      }
    }
  BOOST_AUTO_TEST_SUITE_END()













BOOST_AUTO_TEST_SUITE_END()


#undef    PREFERENCES_TEST_PREFERENCES__MOONDATA_PANEL_DISPLAY_CPP


/**
*** preferences_test_preferences_moondata_panel_display.cpp
**/
