/**
*** \file update_test.cpp
*** \brief Module 'update' unit test file.
*** \details Unit test file for the 'update' module.
**/

/*
** This file is part of moonphase.
** Copyright (C) 2014-2023 Alan Wise <awisesoftware@gmail.com>.
**
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation, either version 3 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/


/**
*** \internal
*** \brief update_test.cpp identifier.
*** \details Identifier for update_test.cpp.
*** \endinternal
**/
#define   UPDATE_TEST_CPP

/* GCOVR_ EXCL_START LCOV_ EXCL_START */


/****
*****
***** INCLUDES
*****
****/

/**
*** \brief Master test suite name.
*** \details The name of the master test suite.
**/
#define   BOOST_TEST_MODULE   "Update"
#include  <boost/test/included/unit_test.hpp>

#include  "http_server_small.cpp"

#include  "update.cpp"


/****
*****
***** DEFINES
*****
****/


/****
*****
***** DATA TYPES
*****
****/


/****
*****
***** CLASSES
*****
****/

class SERVER_C
{
  public:
    SERVER_C(std::string const &Version);
    ~SERVER_C(void);

  private:
    std::unique_ptr<std::thread> m_Thread;
};


/****
*****
***** PROTOTYPES
*****
****/


/****
*****
***** DATA
*****
****/


/****
*****
***** VARIABLES
*****
****/


/****
*****
***** FUNCTIONS
*****
****/

SERVER_C::SERVER_C(std::string const &Version)
{
  m_Thread.reset(new std::thread(HTTPServer,Version));
  usleep(1);  /* Give the server a little time to start. */

  return;
}

SERVER_C::~SERVER_C()
{
  m_Thread->join();
  m_Thread.release();

  return;
}


/****
*****
***** TESTS
*****
****/

BOOST_AUTO_TEST_SUITE(Module__update)
  BOOST_AUTO_TEST_SUITE(Function__CheckForUpdate)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      BOOST_TEST(cURLCallback(nullptr,0,0,nullptr)==0);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      std::string const Version="0.1.2";
      std::string Result;
      BOOST_TEST(cURLCallback(Version.c_str(),
          Version.size(),sizeof(*Version.c_str()),&Result)==
          (Version.size()*sizeof(*Version.c_str())));
      BOOST_TEST(Result=="0.1.2");
    }
    BOOST_AUTO_TEST_CASE(Test_02)
    {
      std::string const Version="1.2.3 ";
      std::string Result;
      BOOST_TEST(cURLCallback(Version.c_str(),
          Version.size(),sizeof(*Version.c_str()),&Result)==
          (Version.size()*sizeof(*Version.c_str())));
      BOOST_TEST(Result=="1.2.3");
    }
    BOOST_AUTO_TEST_CASE(Test_10)
    {
      std::string Version;


      CheckForUpdate(std::string("localhost:1234/current_release"),Version);
      BOOST_TEST(Version=="");
    }
    BOOST_AUTO_TEST_CASE(Test_11)
    {
      std::string Version;
      SERVER_C Server("2.3.4");


      CheckForUpdate(std::string("localhost:1234/current_release"),Version);
      BOOST_TEST(Version=="2.3.4");
    }
  BOOST_AUTO_TEST_SUITE_END()
BOOST_AUTO_TEST_SUITE_END()

/* LCOV_ EXCL_STOP GCOVR_ EXCL_STOP */


#undef    UPDATE_TEST_CPP


/**
*** update_test.cpp
**/
