/**
*** \file preferencesmanager_stub.cpp
*** \brief Module 'preferencesmanager' stub implementation file.
*** \details Stub implementation file for the 'preferencesmanager' module.
**/

/*
** This file is part of moonphase.
** Copyright (C) 2014-2023 Alan Wise <awisesoftware@gmail.com>.
**
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation, either version 3 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/


/**
*** \internal
*** \brief preferencesmanager_stub.cpp identifier.
*** \details Identifier for preferencesmanager_stub.cpp.
*** \endinternal
**/
#define   PREFERENCESMANAGER_STUB_CPP


/****
*****
***** INCLUDES
*****
****/

#include  "preferencesmanager.h"
#include  "preferencesmanager_stub.h"
#include  "sysdefs.h"

#include  <map>
#include  <stdexcept>


/****
*****
***** DEFINES
*****
****/


/****
*****
***** DATA TYPES
*****
****/


/****
*****
***** CLASSES
*****
****/

class PREFERENCESMANAGERPRIVATE_C
{
  public:
    PREFERENCESMANAGERPRIVATE_C(void);

    ~PREFERENCESMANAGERPRIVATE_C(void);
};


/****
*****
***** PROTOTYPES
*****
****/


/****
*****
***** DATA
*****
****/


/****
*****
***** VARIABLES
*****
****/

std::vector<std::string> f_GroupList;
std::map<std::string,bool> f_BoolPreferences;
std::map<std::string,COLOR_C> f_ColorPreferences;
std::map<std::string,std::string> f_StringPreferences;


/****
*****
***** FUNCTIONS
*****
****/

PREFERENCESMANAGERPRIVATE_C::PREFERENCESMANAGERPRIVATE_C(void)
{
  return;
}

PREFERENCESMANAGERPRIVATE_C::~PREFERENCESMANAGERPRIVATE_C(void)
{
  return;
}

PREFERENCESMANAGER_C::PREFERENCESMANAGER_C(void)
{
  return;
}

PREFERENCESMANAGER_C::~PREFERENCESMANAGER_C(void)
{
  return;
}

void PREFERENCESMANAGER_C::BeginGroup(std::string const &Name)
{
  f_GroupList.push_back(Name);

  return;
}

int PREFERENCESMANAGER_C::BeginReadArray(std::string const &Prefix)
{
  UNUSED(Prefix);

  return(0);
}

void PREFERENCESMANAGER_C::BeginWriteArray(std::string const &Prefix,int Size)
{
  UNUSED(Prefix);
  UNUSED(Size);

  return;
}

void PREFERENCESMANAGER_C::EndArray(void)
{
  return;
}

void PREFERENCESMANAGER_C::EndGroup(void)
{
  return;
}

bool PREFERENCESMANAGER_C::
    GetPreference(std::string const &Key,bool Default) const
{
  std::map<std::string,bool>::iterator pIt;


  pIt=f_BoolPreferences.find(Key);
  if (pIt==f_BoolPreferences.end())
    return(Default);

  return(pIt->second);
}

COLOR_C PREFERENCESMANAGER_C::GetPreference(
    std::string const &Key,COLOR_C const &Default) const
{
  UNUSED(Key);
  UNUSED(Default);

  return(COLOR_C());
}

double PREFERENCESMANAGER_C::GetPreference(
    std::string const &Key,double Default) const
{
  UNUSED(Key);
  UNUSED(Default);

  return(0.0);
}

FONT_C PREFERENCESMANAGER_C::
    GetPreference(std::string const &Key,FONT_C const &Default) const
{
  UNUSED(Key);
  UNUSED(Default);

  return(FONT_C());
}

int PREFERENCESMANAGER_C::
    GetPreference(std::string const &Key,int Default) const
{
  UNUSED(Key);
  UNUSED(Default);

  return(0);
}

POSITION_C PREFERENCESMANAGER_C::GetPreference(
    std::string const &Key,POSITION_C const &Default) const
{
  UNUSED(Key);
  UNUSED(Default);

  return(POSITION_C());
}

SIZE_C PREFERENCESMANAGER_C::GetPreference(
    std::string const &Key,SIZE_C const &Default) const
{
  UNUSED(Key);
  UNUSED(Default);

  return(SIZE_C());
}

std::string PREFERENCESMANAGER_C::GetPreference(
    std::string const &Key,std::string const &Default) const
{
  UNUSED(Key);
  UNUSED(Default);

  return(std::string());
}

void PREFERENCESMANAGER_C::Remove(std::string const &Key)
{
  UNUSED(Key);

  return;
}

void PREFERENCESMANAGER_C::SetArrayIndex(int Index)
{
  UNUSED(Index);

  return;
}

void PREFERENCESMANAGER_C::SetPreference(std::string const &Key,bool Value)
{
  PreferencesManagerStub_SetPreference(Key,Value);

  return;
}

void PREFERENCESMANAGER_C::SetPreference(
    std::string const &Key,COLOR_C const &Value)
{
  PreferencesManagerStub_SetPreference(Key,Value);

  return;
}

void PREFERENCESMANAGER_C::SetPreference(std::string const &Key,double Value)
{
  UNUSED(Key);
  UNUSED(Value);

  return;
}

void PREFERENCESMANAGER_C::
    SetPreference(const std::string& Key,FONT_C const &Value)
{
  UNUSED(Key);
  UNUSED(Value);

  return;
}

void
    PREFERENCESMANAGER_C::SetPreference(const std::string& Key,int const &Value)
{
  UNUSED(Key);
  UNUSED(Value);

  return;
}

void PREFERENCESMANAGER_C::SetPreference(
    std::string const &Key,POSITION_C const &Value)
{
  UNUSED(Key);
  UNUSED(Value);

  return;
}

void PREFERENCESMANAGER_C::SetPreference(
    std::string const &Key,SIZE_C const &Value)
{
  UNUSED(Key);
  UNUSED(Value);

  return;
}

void PREFERENCESMANAGER_C::
    SetPreference(std::string const &Key,std::string const &Value)
{
  PreferencesManagerStub_SetPreference(Key,Value);

  return;
}

void PreferencesManagerStub_ClearPreferences(void)
{
  f_GroupList.clear();
  f_BoolPreferences.clear();
  f_ColorPreferences.clear();
  f_StringPreferences.clear();

  return;
}

std::vector<std::string> const & PreferencesManagerStub_GetGroupList(void)
{
  return(f_GroupList);
}

void PreferencesManagerStub_GetPreference(std::string const &Key,bool &Value)
{
  std::map<std::string,bool>::iterator pIt;


  pIt=f_BoolPreferences.find(Key);
  if (pIt==f_BoolPreferences.end())
    throw(std::invalid_argument(Key));

  Value=pIt->second;

  return;
}

void PreferencesManagerStub_SetPreference(std::string const &Key,char const *pValue)
{
  PreferencesManagerStub_SetPreference(Key,std::string(pValue));

  return;
}

void PreferencesManagerStub_GetPreference(std::string const &Key,COLOR_C &Value)
{
  std::map<std::string,COLOR_C>::iterator pIt;


  pIt=f_ColorPreferences.find(Key);
  if (pIt==f_ColorPreferences.end())
    throw(std::invalid_argument(Key));

  Value=pIt->second;

  return;
}

void PreferencesManagerStub_GetPreference(std::string const &Key,std::string &Value)
{
  std::map<std::string,std::string>::iterator pIt;


  pIt=f_StringPreferences.find(Key);
  if (pIt==f_StringPreferences.end())
    throw(std::invalid_argument(Key));

  Value=pIt->second;

  return;
}

void PreferencesManagerStub_SetPreference(std::string const &Key,bool Value)
{
  if (!f_BoolPreferences.insert({Key,Value}).second)
    throw(std::invalid_argument(Key));

  return;
}

void PreferencesManagerStub_SetPreference(std::string const &Key,COLOR_C const &Value)
{
  if (!f_ColorPreferences.insert({Key,Value}).second)
    throw(std::invalid_argument(Key));

  return;
}

void PreferencesManagerStub_SetPreference(std::string const &Key,std::string const &Value)
{
  if (!f_StringPreferences.insert({Key,Value}).second)
    throw(std::invalid_argument(Key));

  return;
}


#undef    PREFERENCESMANAGER_STUB_CPP


/**
*** preferencesmanager_stub.cpp
**/
