#!/bin/bash

# $1 - Project directory (required).
# $2 - Project name (required).
# $3 - Project version (required).

if [ "$#" -ne "3" ]; then
  if [ "$#" -lt "3" ]; then
    Msg="missing parameters."
  else
    Msg="extra parameters."
  fi

  Msg="$Msg\nUsage: $(basename $0) [projectdir] [projectname] [projectversion]"
fi

# Check if in project root.
if [ "$Msg" == "" ]; then
  if [ ! -d "./shell" ]; then
    Msg="this script must be run from the project root directory."
  fi
fi

# Make script easier to read.
ProjDir="$1"
Project="$2"
Version="$3"

# Create a temporary directory.
if [ "$Msg" == "" ]; then
  if [ "$(uname -s)" == "Darwin" ]; then
    TempDir=$(mktemp -d)
  else
    TempDir=$(mktemp -d)
  fi
  echo $TempDir
  if [ $? -ne 0 ]; then
    Msg="unable to create temporary directory."
  else
    # Create the temporary source directory.
    mkdir "${TempDir}/${Project}-${Version}/"
    if [ $? -ne 0 ]; then
      Msg="unable to create temporary source directory."
    else
      # Copy the source to the temporary source directory.
      cp -r . "${TempDir}/${Project}-${Version}/"
      if [ $? -ne 0 ]; then
        Msg="unable to copy source code."
      else
        # Remove unnecessary directories/files.
        rm -rf "${TempDir}/${Project}-${Version}/.build/" 2>/dev/null
        rm -rf "${TempDir}/${Project}-${Version}/.git/" 2>/dev/null
        rm -rf "${TempDir}/${Project}-${Version}/.kdev4/" 2>/dev/null
        rm -rf "${TempDir}/${Project}-${Version}"/*.kdev4 2>/dev/null
        rm -rf "${TempDir}/${Project}-${Version}"/*.tar.gz 2>/dev/null
        rm -rf "${TempDir}/${Project}-${Version}"/*.zip 2>/dev/null

        # Change to the temporary directory.
        pushd "${TempDir}/" >/dev/null
        if [ $? -ne 0 ]; then
          Msg="unable to change to temporary source directory."
        else
          # Create the tar file.
          tar czf "${ProjDir}/${Project}-${Version}.tar.gz" \
              "${Project}-${Version}"
          if [ $? -ne 0 ]; then
            Msg="unable to create tar file."
          else
            # Create the zip file (after removing the old one).
            rm "${ProjDir}/${Project}-${Version}.zip" 2>/dev/null
            zip -pqr9 "${ProjDir}/${Project}-${Version}.zip" \
                "${Project}-${Version}"
            if [ $? -ne 0 ]; then
              Msg="unable to create zip file."
            fi
          fi
          popd >/dev/null
        fi
      fi
      rm -rf "${TempDir}"
    fi
  fi
fi
if [ "$Msg" != "" ]; then
  echo -e "Error: $Msg"
  exit 1
fi
