/**
*** \file datetime_test_datetime.cpp
*** \brief Class 'DATETIME_C' unit test file.
*** \details Unit test file for the 'DATETIME_C' class.
**/

/*
** This file is part of moonphase.
** Copyright (C) 2014-2023 Alan Wise <awisesoftware@gmail.com>.
**
** This program is free software: you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation, either version 3 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program.  If not, see <https://www.gnu.org/licenses/>.
*/


/**
*** \internal
*** \brief datetime_test_datetime.cpp identifier.
*** \details Identifier for datetime_test_datetime.cpp.
*** \endinternal
**/
#define   DATETIME_TEST_DATETIME_CPP


/****
*****
***** INCLUDES
*****
****/


/****
*****
***** DEFINES
*****
****/


/****
*****
***** DATA TYPES
*****
****/


/****
*****
***** CLASSES
*****
****/


/****
*****
***** PROTOTYPES
*****
****/


/****
*****
***** DATA
*****
****/

class TIME_C
{
  public:
    TIME_C(void);
    ~TIME_C(void);
};


/****
*****
***** VARIABLES
*****
****/

static struct tm f_Time;


/****
*****
***** FUNCTIONS
*****
****/

TIME_C::TIME_C(void)
{
  struct tm TimeTM=
  {
    .tm_sec=56,
    .tm_min=24,
    .tm_hour=13-8,
    .tm_mday=22,
    .tm_mon=10,
    .tm_year=99,
    .tm_wday=0,
    .tm_yday=0,
    .tm_isdst=-1
  };
  time_t TimeT;


  TimeT=mktime(&TimeTM);
  f_Time=*gmtime(&TimeT);

  return;
}

TIME_C::~TIME_C(void)
{
  return;
}


/****
*****
***** TESTS
*****
****/

BOOST_AUTO_TEST_SUITE(Class_DATETIMEOPTIONS)
  BOOST_FIXTURE_TEST_SUITE(Function__DefaultConstructor,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options;
      BOOST_TEST(Options.GetDateTimeOptions()==0);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__CopyConstructor,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options.GetUseGMTFlag()==false);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options.GetUseGMTFlag()==true);
    }
    BOOST_AUTO_TEST_CASE(Test_02)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_03)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
    }
    BOOST_AUTO_TEST_CASE(Test_04)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_05)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_06)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
    }
    BOOST_AUTO_TEST_CASE(Test_07)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
    }
    BOOST_AUTO_TEST_CASE(Test_08)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options.GetUseGMTFlag()==true);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Functions__EqualityOperator_InqualityOperator,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_0000)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST((LHS==RHS)==true);
      BOOST_TEST((LHS!=RHS)==false);
    }
    BOOST_AUTO_TEST_CASE(Test_0001)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0002)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0003)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C
          RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((LHS==RHS)==true);
      BOOST_TEST((LHS!=RHS)==false);
    }
    BOOST_AUTO_TEST_CASE(Test_0004)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0005)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0006)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0100)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0101)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((LHS==RHS)==true);
      BOOST_TEST((LHS!=RHS)==false);
    }
    BOOST_AUTO_TEST_CASE(Test_0102)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0103)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C
          RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0104)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0105)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0106)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0107)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0200)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0201)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0202)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((LHS==RHS)==true);
      BOOST_TEST((LHS!=RHS)==false);
    }
    BOOST_AUTO_TEST_CASE(Test_0203)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C
          RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0204)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0205)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0206)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0207)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0300)
    {
      DATETIMEOPTIONS_C
          LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST((LHS==RHS)==true);
      BOOST_TEST((LHS!=RHS)==false);
    }
    BOOST_AUTO_TEST_CASE(Test_0301)
    {
      DATETIMEOPTIONS_C
          LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0302)
    {
      DATETIMEOPTIONS_C
          LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0303)
    {
      DATETIMEOPTIONS_C
          LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C
          RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((LHS==RHS)==true);
      BOOST_TEST((LHS!=RHS)==false);
    }
    BOOST_AUTO_TEST_CASE(Test_0304)
    {
      DATETIMEOPTIONS_C
          LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0305)
    {
      DATETIMEOPTIONS_C
          LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0306)
    {
      DATETIMEOPTIONS_C
          LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0307)
    {
      DATETIMEOPTIONS_C
          LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0400)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0401)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0402)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0403)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C
          RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0404)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((LHS==RHS)==true);
      BOOST_TEST((LHS!=RHS)==false);
    }
    BOOST_AUTO_TEST_CASE(Test_0405)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0406)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0407)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0500)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0501)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0502)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0503)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C
          RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0504)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0505)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((LHS==RHS)==true);
      BOOST_TEST((LHS!=RHS)==false);
    }
    BOOST_AUTO_TEST_CASE(Test_0506)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0507)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0600)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0601)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0602)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0603)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C
          RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0604)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0605)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0606)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((LHS==RHS)==true);
      BOOST_TEST((LHS!=RHS)==false);
    }
    BOOST_AUTO_TEST_CASE(Test_0607)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0700)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0701)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0702)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0703)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C
          RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0704)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0705)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0706)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0707)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((LHS==RHS)==true);
      BOOST_TEST((LHS!=RHS)==false);
    }
    BOOST_AUTO_TEST_CASE(Test_0800)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST((LHS==RHS)==true);
      BOOST_TEST((LHS!=RHS)==false);
    }
    BOOST_AUTO_TEST_CASE(Test_0801)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,false);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0802)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,false);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST((LHS==RHS)==false);
      BOOST_TEST((LHS!=RHS)==true);
    }
    BOOST_AUTO_TEST_CASE(Test_0803)
    {
      DATETIMEOPTIONS_C LHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,false);
      DATETIMEOPTIONS_C RHS(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,false);
      BOOST_TEST((LHS==RHS)==true);
      BOOST_TEST((LHS!=RHS)==false);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__Get24HourFormatFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C
          Options(~DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(Options.Get24HourFormatFlag()==false);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(Options.Get24HourFormatFlag()==true);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__Get4DigitYearFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options(~DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(Options.Get4DigitYearFlag()==false);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(Options.Get4DigitYearFlag()==true);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__GetDateTimeOptions,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_02)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
    }
    BOOST_AUTO_TEST_CASE(Test_03)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_04)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_05)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
    }
    BOOST_AUTO_TEST_CASE(Test_06)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__GetLongDayOfWeekFormatFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options(
          ~DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(Options.GetLongDayOfWeekFormatFlag()==false);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(Options.GetLongDayOfWeekFormatFlag()==true);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__GetLongMonthFormatFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options(
          ~DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(Options.GetLongMonthFormatFlag()==false);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(Options.GetLongMonthFormatFlag()==true);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__GetShowDayOfWeekFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C
          Options(~DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(Options.GetShowDayOfWeekFlag()==false);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(Options.GetShowDayOfWeekFlag()==true);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__GetShowSecondsFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options(~DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(Options.GetShowSecondsFlag()==false);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(Options.GetShowSecondsFlag()==true);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__GetShowTimeZoneFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C
          Options(~DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(Options.GetShowTimeZoneFlag()==false);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(Options.GetShowTimeZoneFlag()==true);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__GetUseGMTFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,false);
      BOOST_TEST(Options.GetUseGMTFlag()==false);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(Options.GetUseGMTFlag()==true);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__Set24HourFormatFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options(~DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.Set24HourFormatFlag(false);
      BOOST_TEST(Options.GetDateTimeOptions()==
          ~DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.Set24HourFormatFlag(true);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__Set4DigitYearFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options(~DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.Set4DigitYearFlag(false);
      BOOST_TEST(Options.GetDateTimeOptions()==
          ~DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.Set4DigitYearFlag(true);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__SetDateTimeOptions,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options(~DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetDateTimeOptions(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetDateTimeOptions(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_02)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetDateTimeOptions(
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_03)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetDateTimeOptions(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
    }
    BOOST_AUTO_TEST_CASE(Test_04)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetDateTimeOptions(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_05)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetDateTimeOptions(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_06)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetDateTimeOptions(
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
    }
    BOOST_AUTO_TEST_CASE(Test_07)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetDateTimeOptions(
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__SetLongDayOfWeekFormatFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options(~DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetLongDayOfWeekFormatFlag(false);
      BOOST_TEST(Options.GetDateTimeOptions()==
          ~DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetLongDayOfWeekFormatFlag(true);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__SetLongMonthFormatFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options(~DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetLongMonthFormatFlag(false);
      BOOST_TEST(Options.GetDateTimeOptions()==
          ~DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetLongMonthFormatFlag(true);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__SetShowDayOfWeekFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options(~DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetShowDayOfWeekFlag(false);
      BOOST_TEST(Options.GetDateTimeOptions()==
          ~DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetShowDayOfWeekFlag(true);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__SetShowSecondsFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options(~DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetShowSecondsFlag(false);
      BOOST_TEST(Options.GetDateTimeOptions()==
          ~DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetShowSecondsFlag(true);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__SetShowTimeZoneFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options(~DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetShowTimeZoneFlag(false);
      BOOST_TEST(Options.GetDateTimeOptions()==
          ~DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetShowTimeZoneFlag(true);
      BOOST_TEST(Options.GetDateTimeOptions()==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__SetUseGMTFlag,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetUseGMTFlag(false);
      BOOST_TEST(Options.GetUseGMTFlag()==false);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      Options.SetUseGMTFlag(false);
      BOOST_TEST(Options.GetUseGMTFlag()==false);
    }
  BOOST_AUTO_TEST_SUITE_END()







  BOOST_FIXTURE_TEST_SUITE(Function__DateTime_Print,TIME_C)
    /*
    ** (pTime==nullptr) || (pOptions==nullptr)
    ** T || F
    ** F || T
    ** F || F - Normal operation.
    */
    BOOST_AUTO_TEST_CASE(ParameterChecking_00)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(DateTime_Print(true,NULL,"%b. %d, %y",Options)=="");
    }
    /*
    ** (DateTimeModeFlag) && (DTFormat.empty())
    ** T && T
    ** T && F
    ** F && T
    ** F && F - Normal operation.
    **/
    BOOST_AUTO_TEST_CASE(ParameterChecking_02)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"",Options)=="");
    }
    BOOST_AUTO_TEST_CASE(ParameterChecking_03)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS,false);
      std::string Result;
      time_t Timet;
      struct tm Timetm;
      char pBuffer[1024];


      Timet=timegm(&f_Time);
      Timetm=*localtime(&Timet);
      strftime(pBuffer,1024,"%F %r",&Timetm);

      Result=DateTime_Print(true,&f_Time,"%F",Options);
//      if ( tzname[1]==nullptr || (!Timetm.tm_isdst) )
        BOOST_TEST(Result==pBuffer);
//      else
//        BOOST_TEST(Result==(pBuffer+std::string(tzname[1])));
    }
    BOOST_AUTO_TEST_CASE(ParameterChecking_04)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"",Options)=="01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(InternalBufferTooSmall)
    {
      std::string LongString(BUFFER_SIZEOF-1,' ');
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,LongString,Options)=="");
    }
    /*
    ** (DateTimeModeFlag) && (!DTFormat.empty()) &&
    **    (DTFormat.size()>=BUFFER_SIZEOF)
    ** T && T && T
    ** F && T && T
    ** T && F && T <- Caught in "ParameterChecking_02".
    ** T && T && F <- Can't happen.
    */
    BOOST_AUTO_TEST_CASE(ParameterChecking_05)
    {
      std::string LongString(BUFFER_SIZEOF,' ');
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,LongString,Options)=="");
    }
    BOOST_AUTO_TEST_CASE(ParameterChecking_06)
    {
      std::string LongString(BUFFER_SIZEOF,' ');
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(
          DateTime_Print(false,&f_Time,LongString,Options)=="01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000000)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000001)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000002)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000003)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000004)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000005)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000006)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000007)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000008)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000009)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00000A)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00000B)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00000C)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00000D)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00000E)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00000F)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000010)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000011)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000012)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000013)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000014)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000015)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000016)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000017)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000018)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000019)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00001A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00001B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00001C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00001D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00001E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00001F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000020)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000021)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000022)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000023)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000024)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000025)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000026)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000027)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000028)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000029)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00002A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00002B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00002C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00002D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00002E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00002F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000030)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000031)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000032)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000033)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000034)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000035)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000036)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000037)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000038)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000039)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00003A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00003B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00003C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00003D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00003E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00003F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000040)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000041)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000042)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000043)
    {
      DATETIMEOPTIONS_C  Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000044)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000045)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000046)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000047)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000048)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000049)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00004A)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00004B)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00004C)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00004D)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00004E)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00004F)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000050)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);

      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000051)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000052)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000053)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000054)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000055)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000056)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000057)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000058)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000059)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00005A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00005B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00005C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00005D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00005E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00005F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000060)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000061)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000062)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000063)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000064)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000065)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000066)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000067)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Nov. 22, 1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000068)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000069)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00006A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00006B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00006C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00006D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00006E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00006F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "November 22, 1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000070)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000071)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000072)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000073)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., Nov. 22, 1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000074)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000075)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000076)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000077)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, Nov. 22, 1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000078)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000079)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00007A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00007B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Mon., November 22, 1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00007C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00007D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00007E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00007F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%b. %d, %y",Options)==
          "Monday, November 22, 1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000100)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000101)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000102)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000103)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000104)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000105)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000106)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000107)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000108)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000109)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00010A)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00010B)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00010C)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00010D)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00010E)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00010F)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000110)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000111)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000112)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000113)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000114)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000115)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000116)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000117)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000118)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000119)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00011A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00011B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00011C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00011D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00011E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00011F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000120)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000121)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000122)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000123)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000124)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000125)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000126)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000127)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000128)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000129)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00012A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00012B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00012C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00012D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00012E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00012F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000130)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000131)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000132)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000133)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000134)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000135)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000136)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000137)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000138)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000139)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00013A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00013B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00013C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00013D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00013E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00013F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000140)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000141)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
            DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000142)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
        DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000143)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000144)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000145)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000146)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000147)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000148)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000149)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00014A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00014B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00014C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00014D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00014E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00014F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000150)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000151)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000152)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000153)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000154)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000155)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000156)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000157)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000158)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000159)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00015A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00015B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00015C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00015D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00015E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00015F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000160)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000161)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000162)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000163)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000164)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000165)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000166)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000167)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000168)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000169)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00016A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00016B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00016C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00016D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00016E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00016F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "11/22/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000170)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000171)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000172)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000173)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000174)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000175)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000176)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000177)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000178)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000179)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00017A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00017B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Mon., 11/22/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00017C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00017D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00017E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00017F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%m/%d/%y",Options)==
          "Monday, 11/22/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000200)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000201)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000202)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000203)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000204)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000205)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000206)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000207)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000208)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000209)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00020A)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00020B)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00020C)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00020D)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00020E)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00020F)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000210)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000211)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000212)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000213)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000214)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000215)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000216)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000217)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000218)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000219)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00021A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00021B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00021C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00021D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_00021E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00021F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_000220)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000221)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000222)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000223)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000224)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000225)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000226)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000227)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000228)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000229)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00022A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00022B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00022C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00022D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00022E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00022F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000230)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000231)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000232)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000233)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000234)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000235)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000236)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000237)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000238)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_000239)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00023A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00023B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00023C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00023D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_00023E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_00023F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_000400)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000401)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000402)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000403)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000404)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000405)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000406)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000407)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000408)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000409)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00040A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00040B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00040C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00040D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00040E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00040F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000410)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000411)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000412)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000413)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000414)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000415)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000416)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000417)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000418)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000419)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00041A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00041B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00041C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00041D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00041E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00041F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000420)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000421)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000422)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000423)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000424)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000425)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000426)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000427)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000428)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000429)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00042A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00042B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00042C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00042D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00042E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00042F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "22/11/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000430)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000431)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000432)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000433)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000434)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000435)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000436)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000437)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000438)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_000439)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00043A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00043B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Mon., 22/11/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00043C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00043D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/99 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00043E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_00043F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(true,&f_Time,"%d/%m/%y",Options)==
          "Monday, 22/11/1999 13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010000)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010001)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010002)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010003)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010004)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010005)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010006)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010007)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010008)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010009)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01000A)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01000B)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01000C)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01000D)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01000E)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01000F)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010010)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010011)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010012)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010013)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010014)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010015)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010016)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010017)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010018)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010019)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01001A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01001B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01001C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01001D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01001E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01001F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010020)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010021)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010022)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010023)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010024)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010025)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010026)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010027)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010028)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010029)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01002A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01002B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01002C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01002D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01002E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01002F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010030)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010031)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010032)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010033)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010034)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010035)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010036)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010037)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010038)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010039)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01003A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01003B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01003C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01003D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01003E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01003F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010040)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010041)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010042)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010043)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010044)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010045)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010046)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010047)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010048)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010049)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01004A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01004B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01004C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01004D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01004E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01004F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010050)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010051)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010052)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010053)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010054)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010055)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010056)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010057)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010058)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010059)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01005A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01005B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01005C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01005D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01005E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01005F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010060)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010061)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010062)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010063)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010064)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010065)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010066)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010067)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010068)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010069)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01006A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01006B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01006C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01006D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01006E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01006F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010070)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010071)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010072)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010073)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010074)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010075)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010076)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010077)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010078)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010079)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01007A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01007B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01007C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01007D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01007E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01007F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%b. %d, %y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010100)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010101)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010102)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010103)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010104)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010105)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010106)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010107)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010108)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010109)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01010A)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01010B)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01010C)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01010D)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01010E)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01010F)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010110)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010111)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010112)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010113)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010114)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010115)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010116)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010117)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010118)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010119)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01011A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01011B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01011C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01011D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01011E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01011F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010120)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010121)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010122)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010123)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010124)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010125)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010126)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010127)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010128)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010129)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01012A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01012B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01012C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01012D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01012E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01012F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010130)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010131)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010132)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010133)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010134)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010135)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010136)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010137)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010138)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010139)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01013A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01013B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01013C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01013D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01013E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01013F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010140)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010141)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010142)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010143)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010144)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010145)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010146)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010147)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010148)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010149)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01014A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01014B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01014C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01014D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01014E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01014F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010150)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010151)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010152)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010153)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010154)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010155)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010156)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010157)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010158)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010159)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01015A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01015B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01015C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01015D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01015E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01015F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010160)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010161)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010162)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010163)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010164)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010165)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010166)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010167)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010168)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010169)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01016A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01016B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01016C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01016D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01016E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01016F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010170)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010171)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010172)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010173)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010174)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010175)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010176)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010177)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010178)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010179)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01017A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01017B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01017C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01017D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01017E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01017F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%m/%d/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010200)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010201)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010202)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010203)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010204)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010205)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010206)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010207)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010208)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010209)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01020A)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01020B)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01020C)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01020D)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01020E)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01020F)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010210)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010211)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010212)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010213)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010214)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010215)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010216)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010217)
    {
      DATETIMEOPTIONS_C Options(
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010218)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010219)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01021A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01021B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01021C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01021D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_01021E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01021F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24");
    }
    BOOST_AUTO_TEST_CASE(Test_010220)
    {
      DATETIMEOPTIONS_C
          Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010221)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010222)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010223)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010224)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010225)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010226)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010227)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010228)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010229)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01022A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01022B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01022C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01022D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01022E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01022F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010230)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010231)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010232)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010233)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010234)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010235)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010236)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010237)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010238)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_010239)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01023A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01023B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01023C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01023D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_01023E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM");
    }
    BOOST_AUTO_TEST_CASE(Test_01023F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56");
    }
    BOOST_AUTO_TEST_CASE(Test_010240)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010241)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010242)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010243)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010244)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010245)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010246)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010247)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010248)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010249)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01024A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01024B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01024C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01024D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01024E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01024F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010250)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010251)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010252)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010253)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010254)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010255)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010256)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010257)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010258)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010259)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01025A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01025B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01025C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01025D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01025E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01025F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010260)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010261)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010262)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010263)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010264)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010265)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010266)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010267)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010268)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010269)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01026A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01026B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01026C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01026D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01026E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01026F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010270)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010271)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010272)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010273)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010274)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010275)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010276)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010277)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010278)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_010279)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01027A)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01027B)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01027C)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01027D)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01027E)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "01:24:56 PM GMT");
    }
    BOOST_AUTO_TEST_CASE(Test_01027F)
    {
      DATETIMEOPTIONS_C Options(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR,true);
      BOOST_TEST(DateTime_Print(false,&f_Time,"%d/%m/%y",Options)==
          "13:24:56 GMT");
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__DATETIMEOPTIONS_F_operatorNOT,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options=DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL;
      BOOST_TEST(~Options==~DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_01)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options=DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT;
      BOOST_TEST(~Options==~DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_02)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options=DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR;
      BOOST_TEST(~Options==~DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
    }
    BOOST_AUTO_TEST_CASE(Test_03)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options=DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT;
      BOOST_TEST(
          ~Options==~DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_04)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options=DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT;
      BOOST_TEST(~Options==~DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_05)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options=DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK;
      BOOST_TEST(~Options==~DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
    }
    BOOST_AUTO_TEST_CASE(Test_06)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options=DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS;
      BOOST_TEST(~Options==~DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
    }
    BOOST_AUTO_TEST_CASE(Test_07)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options=~DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE;
      BOOST_TEST(~Options==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__DATETIMEOPTIONS_F_operatorAND,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_0000)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0001)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0002)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0003)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0004)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0005)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0006)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0007)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0100)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0101)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0102)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0103)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0104)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0105)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0106)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0107)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0200)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0201)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0202)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
    }
    BOOST_AUTO_TEST_CASE(Test_0203)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0204)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0205)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0206)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0207)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0300)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0301)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0302)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0303)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0&Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0304)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0305)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0306)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0307)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0400)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0401)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0402)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0403)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0404)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0&Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0405)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0406)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0407)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0500)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0501)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0502)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0503)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0504)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0505)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
    }
    BOOST_AUTO_TEST_CASE(Test_0506)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0507)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0600)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0601)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0602)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0603)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0604)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0605)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0606)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
    }
    BOOST_AUTO_TEST_CASE(Test_0607)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0700)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0701)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0702)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0703)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0704)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0705)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0706)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0707)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0&Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(
      Function__DATETIMEOPTIONS_F_operatorANDEQUAL,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_0000)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0001)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0002)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0003)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0004)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0005)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0006)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0007)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0100)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0101)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0102)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0103)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0104)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0105)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0106)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0107)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0200)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0201)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0202)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
    }
    BOOST_AUTO_TEST_CASE(Test_0203)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0204)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0205)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0206)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0207)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0300)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0301)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0302)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0303)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0&=Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0304)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0305)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0306)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0307)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0400)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0401)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0402)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0403)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0404)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0405)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0406)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0407)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0500)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0501)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0502)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0503)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0504)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0505)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((Options0&=Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
    }
    BOOST_AUTO_TEST_CASE(Test_0506)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0507)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0600)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0601)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0602)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0603)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0604)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0605)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0606)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
    }
    BOOST_AUTO_TEST_CASE(Test_0607)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0700)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0701)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0702)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0703)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0704)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0705)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0706)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0707)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0&=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__DATETIMEOPTIONS_F_operatorOR,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_0000)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0001)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0002)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
    }
    BOOST_AUTO_TEST_CASE(Test_0003)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0004)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0005)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
    }
    BOOST_AUTO_TEST_CASE(Test_0006)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
    }
    BOOST_AUTO_TEST_CASE(Test_0007)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
    }
    BOOST_AUTO_TEST_CASE(Test_0100)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0101)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0102)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
    }
    BOOST_AUTO_TEST_CASE(Test_0103)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0104)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0105)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
    }
    BOOST_AUTO_TEST_CASE(Test_0106)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
    }
    BOOST_AUTO_TEST_CASE(Test_0107)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
    }
    BOOST_AUTO_TEST_CASE(Test_0200)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
    }
    BOOST_AUTO_TEST_CASE(Test_0201)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0202)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
    }
    BOOST_AUTO_TEST_CASE(Test_0203)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0204)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0205)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
    }
    BOOST_AUTO_TEST_CASE(Test_0206)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
    }
    BOOST_AUTO_TEST_CASE(Test_0207)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
    }
    BOOST_AUTO_TEST_CASE(Test_0300)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST((Options0|Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0301)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0302)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
    }
    BOOST_AUTO_TEST_CASE(Test_0303)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0304)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0305)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
    }
    BOOST_AUTO_TEST_CASE(Test_0306)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
    }
    BOOST_AUTO_TEST_CASE(Test_0307)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
    }
    BOOST_AUTO_TEST_CASE(Test_0400)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST((Options0|Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0401)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((Options0|Options1)==(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0402)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((Options0|Options1)==(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
    }
    BOOST_AUTO_TEST_CASE(Test_0403)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|Options1)==(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0404)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0405)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((Options0|Options1)==(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
    }
    BOOST_AUTO_TEST_CASE(Test_0406)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((Options0|Options1)==(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
    }
    BOOST_AUTO_TEST_CASE(Test_0407)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((Options0|Options1)==(
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
    }
    BOOST_AUTO_TEST_CASE(Test_0500)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
    }
    BOOST_AUTO_TEST_CASE(Test_0501)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0502)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
    }
    BOOST_AUTO_TEST_CASE(Test_0503)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0504)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0505)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
    }
    BOOST_AUTO_TEST_CASE(Test_0506)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
    }
    BOOST_AUTO_TEST_CASE(Test_0507)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
    }
    BOOST_AUTO_TEST_CASE(Test_0600)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
    }
    BOOST_AUTO_TEST_CASE(Test_0601)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0602)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
    }
    BOOST_AUTO_TEST_CASE(Test_0603)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0604)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0605)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
    }
    BOOST_AUTO_TEST_CASE(Test_0606)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
    }
    BOOST_AUTO_TEST_CASE(Test_0607)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0|Options1)==(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
    }
    BOOST_AUTO_TEST_CASE(Test_0700)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
    }
    BOOST_AUTO_TEST_CASE(Test_0701)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0702)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
    }
    BOOST_AUTO_TEST_CASE(Test_0703)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0704)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0705)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
    }
    BOOST_AUTO_TEST_CASE(Test_0706)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((Options0|Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
    }
    BOOST_AUTO_TEST_CASE(Test_0707)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0|Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_FIXTURE_TEST_SUITE(Function__DATETIMEOPTIONS_F_operatorOREQUAL,TIME_C)
    BOOST_AUTO_TEST_CASE(Test_0000)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0|=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
    }
    BOOST_AUTO_TEST_CASE(Test_0001)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0|=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0002)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0|=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
    }
    BOOST_AUTO_TEST_CASE(Test_0003)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|=Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0004)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|=Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0005)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((Options0|=Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
    }
    BOOST_AUTO_TEST_CASE(Test_0006)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0|=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
    }
    BOOST_AUTO_TEST_CASE(Test_0007)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(
          (Options0|=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
    }
    BOOST_AUTO_TEST_CASE(Test_0100)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0|=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0101)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(
          (Options0|=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0102)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
    }
    BOOST_AUTO_TEST_CASE(Test_0103)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0104)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0105)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
    }
    BOOST_AUTO_TEST_CASE(Test_0106)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
    }
    BOOST_AUTO_TEST_CASE(Test_0107)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
    }
    BOOST_AUTO_TEST_CASE(Test_0200)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0|=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
    }
    BOOST_AUTO_TEST_CASE(Test_0201)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0202)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(
          (Options0|=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
    }
    BOOST_AUTO_TEST_CASE(Test_0203)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0204)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0205)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
    }
    BOOST_AUTO_TEST_CASE(Test_0206)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
    }
    BOOST_AUTO_TEST_CASE(Test_0207)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
    }
    BOOST_AUTO_TEST_CASE(Test_0300)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST((Options0|=Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(
          Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0301)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0302)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
    }
    BOOST_AUTO_TEST_CASE(Test_0303)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|=Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST(Options0==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0304)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0305)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
    }
    BOOST_AUTO_TEST_CASE(Test_0306)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
    }
    BOOST_AUTO_TEST_CASE(Test_0307)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
    }
    BOOST_AUTO_TEST_CASE(Test_0400)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST((Options0|=Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(Options0==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0401)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0402)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
    }
    BOOST_AUTO_TEST_CASE(Test_0403)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0404)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|=Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST(Options0==
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
    }
    BOOST_AUTO_TEST_CASE(Test_0405)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
    }
    BOOST_AUTO_TEST_CASE(Test_0406)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
    }
    BOOST_AUTO_TEST_CASE(Test_0407)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
    }
    BOOST_AUTO_TEST_CASE(Test_0500)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST((Options0|=Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(Options0==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
    }
    BOOST_AUTO_TEST_CASE(Test_0501)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0502)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
    }
    BOOST_AUTO_TEST_CASE(Test_0503)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0504)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0505)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((Options0|=Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST(Options0==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
    }
    BOOST_AUTO_TEST_CASE(Test_0506)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
    }
    BOOST_AUTO_TEST_CASE(Test_0507)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
    }
    BOOST_AUTO_TEST_CASE(Test_0600)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0|=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
    }
    BOOST_AUTO_TEST_CASE(Test_0601)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0602)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
    }
    BOOST_AUTO_TEST_CASE(Test_0603)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0604)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0605)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
    }
    BOOST_AUTO_TEST_CASE(Test_0606)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(
          (Options0|=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
    }
    BOOST_AUTO_TEST_CASE(Test_0607)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE));
    }
    BOOST_AUTO_TEST_CASE(Test_0700)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_CLEARALL);
      BOOST_TEST(
          (Options0|=Options1)==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(Options0==DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
    }
    BOOST_AUTO_TEST_CASE(Test_0701)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_24HOURFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0702)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_4DIGITYEAR));
    }
    BOOST_AUTO_TEST_CASE(Test_0703)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGDAYOFWEEKFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0704)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_LONGMONTHFORMAT));
    }
    BOOST_AUTO_TEST_CASE(Test_0705)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWDAYOFWEEK));
    }
    BOOST_AUTO_TEST_CASE(Test_0706)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS);
      BOOST_TEST((Options0|=Options1)==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
      BOOST_TEST(Options0==
          (DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE|
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWSECONDS));
    }
    BOOST_AUTO_TEST_CASE(Test_0707)
    {
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options0(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      DATETIMEOPTIONS_C::DATETIMEOPTIONS_F
          Options1(DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST((Options0|=Options1)==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
      BOOST_TEST(Options0==
          DATETIMEOPTIONS_C::DATETIMEOPTION_SHOWTIMEZONE);
    }
  BOOST_AUTO_TEST_SUITE_END()

  BOOST_AUTO_TEST_SUITE(Function__Load_Save)
    BOOST_AUTO_TEST_CASE(Test_00)
    {
      PREFERENCESMANAGER_C Manager;
      DATETIMEOPTIONS_C SOptions;
      DATETIMEOPTIONS_C LOptions;


      unlink("todo.ini");

      SOptions.Save(&Manager);

      LOptions.Load(&Manager);

      unlink("todo.ini");

      BOOST_TEST((SOptions==LOptions));
    }
  BOOST_AUTO_TEST_SUITE_END()
BOOST_AUTO_TEST_SUITE_END()


#undef    DATETIME_TEST_DATETIME_CPP


/**
*** datetime_test_datetime.cpp
**/
